Class: Google::Apis::NetappV1::Backup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/netapp_v1/classes.rb,
lib/google/apis/netapp_v1/representations.rb,
lib/google/apis/netapp_v1/representations.rb

Overview

A NetApp Backup.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Backup

Returns a new instance of Backup.



276
277
278
# File 'lib/google/apis/netapp_v1/classes.rb', line 276

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backup_regionString

Output only. Region in which backup is stored. Format: projects/project_id/ locations/location` Corresponds to the JSON propertybackupRegion`

Returns:

  • (String)


191
192
193
# File 'lib/google/apis/netapp_v1/classes.rb', line 191

def backup_region
  @backup_region
end

#backup_typeString

Output only. Type of backup, manually created or created by a backup policy. Corresponds to the JSON property backupType

Returns:

  • (String)


196
197
198
# File 'lib/google/apis/netapp_v1/classes.rb', line 196

def backup_type
  @backup_type
end

#chain_storage_bytesFixnum

Output only. Total size of all backups in a chain in bytes = baseline backup size + sum(incremental backup size) Corresponds to the JSON property chainStorageBytes

Returns:

  • (Fixnum)


202
203
204
# File 'lib/google/apis/netapp_v1/classes.rb', line 202

def chain_storage_bytes
  @chain_storage_bytes
end

#create_timeString

Output only. The time when the backup was created. Corresponds to the JSON property createTime

Returns:

  • (String)


207
208
209
# File 'lib/google/apis/netapp_v1/classes.rb', line 207

def create_time
  @create_time
end

#descriptionString

A description of the backup with 2048 characters or less. Requests with longer descriptions will be rejected. Corresponds to the JSON property description

Returns:

  • (String)


213
214
215
# File 'lib/google/apis/netapp_v1/classes.rb', line 213

def description
  @description
end

#enforced_retention_end_timeString

Output only. The time until which the backup is not deletable. Corresponds to the JSON property enforcedRetentionEndTime

Returns:

  • (String)


218
219
220
# File 'lib/google/apis/netapp_v1/classes.rb', line 218

def enforced_retention_end_time
  @enforced_retention_end_time
end

#labelsHash<String,String>

Resource labels to represent user provided metadata. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


223
224
225
# File 'lib/google/apis/netapp_v1/classes.rb', line 223

def labels
  @labels
end

#nameString

Identifier. The resource name of the backup. Format: projects/project_id/ locations/location/backupVaults/backup_vault_id/backups/backup_id`. Corresponds to the JSON propertyname`

Returns:

  • (String)


229
230
231
# File 'lib/google/apis/netapp_v1/classes.rb', line 229

def name
  @name
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


234
235
236
# File 'lib/google/apis/netapp_v1/classes.rb', line 234

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Reserved for future use Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


240
241
242
# File 'lib/google/apis/netapp_v1/classes.rb', line 240

def satisfies_pzs
  @satisfies_pzs
end

#source_snapshotString

If specified, backup will be created from the given snapshot. If not specified, there will be a new snapshot taken to initiate the backup creation. Format: projects/project_id/locations/location/volumes/volume_id/snapshots/ snapshot_id` Corresponds to the JSON propertysourceSnapshot`

Returns:

  • (String)


249
250
251
# File 'lib/google/apis/netapp_v1/classes.rb', line 249

def source_snapshot
  @source_snapshot
end

#source_volumeString

Volume full name of this backup belongs to. Either source_volume or ontap_source should be provided. Format: projects/projects_id/locations/ location/volumes/volume_id` Corresponds to the JSON propertysourceVolume`

Returns:

  • (String)


256
257
258
# File 'lib/google/apis/netapp_v1/classes.rb', line 256

def source_volume
  @source_volume
end

#stateString

Output only. The backup state. Corresponds to the JSON property state

Returns:

  • (String)


261
262
263
# File 'lib/google/apis/netapp_v1/classes.rb', line 261

def state
  @state
end

#volume_regionString

Output only. Region of the volume from which the backup was created. Format: projects/project_id/locations/location` Corresponds to the JSON propertyvolumeRegion`

Returns:

  • (String)


267
268
269
# File 'lib/google/apis/netapp_v1/classes.rb', line 267

def volume_region
  @volume_region
end

#volume_usage_bytesFixnum

Output only. Size of the file system when the backup was created. When creating a new volume from the backup, the volume capacity will have to be at least as big. Corresponds to the JSON property volumeUsageBytes

Returns:

  • (Fixnum)


274
275
276
# File 'lib/google/apis/netapp_v1/classes.rb', line 274

def volume_usage_bytes
  @volume_usage_bytes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
# File 'lib/google/apis/netapp_v1/classes.rb', line 281

def update!(**args)
  @backup_region = args[:backup_region] if args.key?(:backup_region)
  @backup_type = args[:backup_type] if args.key?(:backup_type)
  @chain_storage_bytes = args[:chain_storage_bytes] if args.key?(:chain_storage_bytes)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @enforced_retention_end_time = args[:enforced_retention_end_time] if args.key?(:enforced_retention_end_time)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @source_snapshot = args[:source_snapshot] if args.key?(:source_snapshot)
  @source_volume = args[:source_volume] if args.key?(:source_volume)
  @state = args[:state] if args.key?(:state)
  @volume_region = args[:volume_region] if args.key?(:volume_region)
  @volume_usage_bytes = args[:volume_usage_bytes] if args.key?(:volume_usage_bytes)
end