Class: Google::Apis::NetappV1::BackupConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/netapp_v1/classes.rb,
lib/google/apis/netapp_v1/representations.rb,
lib/google/apis/netapp_v1/representations.rb

Overview

BackupConfig contains backup related config on a volume.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackupConfig

Returns a new instance of BackupConfig.



329
330
331
# File 'lib/google/apis/netapp_v1/classes.rb', line 329

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backup_chain_bytesFixnum

Output only. Total size of all backups in a chain in bytes = baseline backup size + sum(incremental backup size). Corresponds to the JSON property backupChainBytes

Returns:

  • (Fixnum)


308
309
310
# File 'lib/google/apis/netapp_v1/classes.rb', line 308

def backup_chain_bytes
  @backup_chain_bytes
end

#backup_policiesArray<String>

Optional. When specified, schedule backups will be created based on the policy configuration. Corresponds to the JSON property backupPolicies

Returns:

  • (Array<String>)


314
315
316
# File 'lib/google/apis/netapp_v1/classes.rb', line 314

def backup_policies
  @backup_policies
end

#backup_vaultString

Optional. Name of backup vault. Format: projects/project_id/locations/ location/backupVaults/backup_vault_id Corresponds to the JSON property backupVault

Returns:

  • (String)


320
321
322
# File 'lib/google/apis/netapp_v1/classes.rb', line 320

def backup_vault
  @backup_vault
end

#scheduled_backup_enabledBoolean Also known as: scheduled_backup_enabled?

Optional. When set to true, scheduled backup is enabled on the volume. This field should be nil when there's no backup policy attached. Corresponds to the JSON property scheduledBackupEnabled

Returns:

  • (Boolean)


326
327
328
# File 'lib/google/apis/netapp_v1/classes.rb', line 326

def scheduled_backup_enabled
  @scheduled_backup_enabled
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



334
335
336
337
338
339
# File 'lib/google/apis/netapp_v1/classes.rb', line 334

def update!(**args)
  @backup_chain_bytes = args[:backup_chain_bytes] if args.key?(:backup_chain_bytes)
  @backup_policies = args[:backup_policies] if args.key?(:backup_policies)
  @backup_vault = args[:backup_vault] if args.key?(:backup_vault)
  @scheduled_backup_enabled = args[:scheduled_backup_enabled] if args.key?(:scheduled_backup_enabled)
end