Class: Google::Apis::NetappV1::BackupPolicy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/netapp_v1/classes.rb,
lib/google/apis/netapp_v1/representations.rb,
lib/google/apis/netapp_v1/representations.rb

Overview

Backup Policy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackupPolicy

Returns a new instance of BackupPolicy.



408
409
410
# File 'lib/google/apis/netapp_v1/classes.rb', line 408

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#assigned_volume_countFixnum

Output only. The total number of volumes assigned by this backup policy. Corresponds to the JSON property assignedVolumeCount

Returns:

  • (Fixnum)


355
356
357
# File 'lib/google/apis/netapp_v1/classes.rb', line 355

def assigned_volume_count
  @assigned_volume_count
end

#create_timeString

Output only. The time when the backup policy was created. Corresponds to the JSON property createTime

Returns:

  • (String)


360
361
362
# File 'lib/google/apis/netapp_v1/classes.rb', line 360

def create_time
  @create_time
end

#daily_backup_limitFixnum

Number of daily backups to keep. Note that the minimum daily backup limit is 2. Corresponds to the JSON property dailyBackupLimit

Returns:

  • (Fixnum)


365
366
367
# File 'lib/google/apis/netapp_v1/classes.rb', line 365

def daily_backup_limit
  @daily_backup_limit
end

#descriptionString

Description of the backup policy. Corresponds to the JSON property description

Returns:

  • (String)


370
371
372
# File 'lib/google/apis/netapp_v1/classes.rb', line 370

def description
  @description
end

#enabledBoolean Also known as: enabled?

If enabled, make backups automatically according to the schedules. This will be applied to all volumes that have this policy attached and enforced on volume level. If not specified, default is true. Corresponds to the JSON property enabled

Returns:

  • (Boolean)


377
378
379
# File 'lib/google/apis/netapp_v1/classes.rb', line 377

def enabled
  @enabled
end

#labelsHash<String,String>

Resource labels to represent user provided metadata. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


383
384
385
# File 'lib/google/apis/netapp_v1/classes.rb', line 383

def labels
  @labels
end

#monthly_backup_limitFixnum

Number of monthly backups to keep. Note that the sum of daily, weekly and monthly backups should be greater than 1. Corresponds to the JSON property monthlyBackupLimit

Returns:

  • (Fixnum)


389
390
391
# File 'lib/google/apis/netapp_v1/classes.rb', line 389

def monthly_backup_limit
  @monthly_backup_limit
end

#nameString

Identifier. The resource name of the backup policy. Format: projects/ project_id/locations/location/backupPolicies/backup_policy_id`. Corresponds to the JSON propertyname`

Returns:

  • (String)


395
396
397
# File 'lib/google/apis/netapp_v1/classes.rb', line 395

def name
  @name
end

#stateString

Output only. The backup policy state. Corresponds to the JSON property state

Returns:

  • (String)


400
401
402
# File 'lib/google/apis/netapp_v1/classes.rb', line 400

def state
  @state
end

#weekly_backup_limitFixnum

Number of weekly backups to keep. Note that the sum of daily, weekly and monthly backups should be greater than 1. Corresponds to the JSON property weeklyBackupLimit

Returns:

  • (Fixnum)


406
407
408
# File 'lib/google/apis/netapp_v1/classes.rb', line 406

def weekly_backup_limit
  @weekly_backup_limit
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



413
414
415
416
417
418
419
420
421
422
423
424
# File 'lib/google/apis/netapp_v1/classes.rb', line 413

def update!(**args)
  @assigned_volume_count = args[:assigned_volume_count] if args.key?(:assigned_volume_count)
  @create_time = args[:create_time] if args.key?(:create_time)
  @daily_backup_limit = args[:daily_backup_limit] if args.key?(:daily_backup_limit)
  @description = args[:description] if args.key?(:description)
  @enabled = args[:enabled] if args.key?(:enabled)
  @labels = args[:labels] if args.key?(:labels)
  @monthly_backup_limit = args[:monthly_backup_limit] if args.key?(:monthly_backup_limit)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
  @weekly_backup_limit = args[:weekly_backup_limit] if args.key?(:weekly_backup_limit)
end