Class: Google::Apis::NetappV1::BackupSource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/netapp_v1/classes.rb,
lib/google/apis/netapp_v1/representations.rb,
lib/google/apis/netapp_v1/representations.rb

Overview

Represents the backup source of the restore operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackupSource

Returns a new instance of BackupSource.



498
499
500
# File 'lib/google/apis/netapp_v1/classes.rb', line 498

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backupString

Required. The backup resource name. Corresponds to the JSON property backup

Returns:

  • (String)


489
490
491
# File 'lib/google/apis/netapp_v1/classes.rb', line 489

def backup
  @backup
end

#file_listArray<String>

Optional. List of files to be restored in the form of their absolute path as in source volume. If provided, only these files will be restored. If not provided, the entire backup will be restored (Full Backup Restore) Corresponds to the JSON property fileList

Returns:

  • (Array<String>)


496
497
498
# File 'lib/google/apis/netapp_v1/classes.rb', line 496

def file_list
  @file_list
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



503
504
505
506
# File 'lib/google/apis/netapp_v1/classes.rb', line 503

def update!(**args)
  @backup = args[:backup] if args.key?(:backup)
  @file_list = args[:file_list] if args.key?(:file_list)
end