Class: Google::Apis::NetappV1::BlockDevice
- Inherits:
-
Object
- Object
- Google::Apis::NetappV1::BlockDevice
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/netapp_v1/classes.rb,
lib/google/apis/netapp_v1/representations.rb,
lib/google/apis/netapp_v1/representations.rb
Overview
Block device represents the device(s) which are stored in the block volume.
Instance Attribute Summary collapse
-
#host_groups ⇒ Array<String>
Optional.
-
#identifier ⇒ String
Output only.
-
#name ⇒ String
Optional.
-
#os_type ⇒ String
Required.
-
#size_gib ⇒ Fixnum
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BlockDevice
constructor
A new instance of BlockDevice.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BlockDevice
Returns a new instance of BlockDevice.
655 656 657 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 655 def initialize(**args) update!(**args) end |
Instance Attribute Details
#host_groups ⇒ Array<String>
Optional. A list of host groups that identify hosts that can mount the block
volume. Format: projects/project_id/locations/location/hostGroups/
host_group_id`This field can be updated after the block device is created.
Corresponds to the JSON propertyhostGroups`
624 625 626 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 624 def host_groups @host_groups end |
#identifier ⇒ String
Output only. Device identifier of the block volume. This represents
lun_serial_number for iSCSI volumes.
Corresponds to the JSON property identifier
630 631 632 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 630 def identifier @identifier end |
#name ⇒ String
Optional. User-defined name for the block device, unique within the volume. In
case no user input is provided, name will be auto-generated in the backend.
The name must meet the following requirements: * Be between 1 and 255
characters long. * Contain only uppercase or lowercase letters (A-Z, a-z),
numbers (0-9), and the following special characters: "-", "_", "", "", ".". *
Spaces are not allowed.
Corresponds to the JSON property name
640 641 642 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 640 def name @name end |
#os_type ⇒ String
Required. Immutable. The OS type of the volume. This field can't be changed
after the block device is created.
Corresponds to the JSON property osType
646 647 648 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 646 def os_type @os_type end |
#size_gib ⇒ Fixnum
Optional. The size of the block device in GiB. Any value provided for the
size_gib field during volume creation is ignored. The block device's size is
system-managed and will be set to match the parent Volume's capacity_gib.
Corresponds to the JSON property sizeGib
653 654 655 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 653 def size_gib @size_gib end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
660 661 662 663 664 665 666 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 660 def update!(**args) @host_groups = args[:host_groups] if args.key?(:host_groups) @identifier = args[:identifier] if args.key?(:identifier) @name = args[:name] if args.key?(:name) @os_type = args[:os_type] if args.key?(:os_type) @size_gib = args[:size_gib] if args.key?(:size_gib) end |