Class: Google::Apis::NetappV1::CacheConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/netapp_v1/classes.rb,
lib/google/apis/netapp_v1/representations.rb,
lib/google/apis/netapp_v1/representations.rb

Overview

Configuration of the cache volume.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CacheConfig

Returns a new instance of CacheConfig.



665
666
667
# File 'lib/google/apis/netapp_v1/classes.rb', line 665

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cache_pre_populateGoogle::Apis::NetappV1::CachePrePopulate

Pre-populate cache volume with data from the origin volume. Corresponds to the JSON property cachePrePopulate



643
644
645
# File 'lib/google/apis/netapp_v1/classes.rb', line 643

def cache_pre_populate
  @cache_pre_populate
end

#cache_pre_populate_stateString

Output only. State of the prepopulation job indicating how the prepopulation is progressing. Corresponds to the JSON property cachePrePopulateState

Returns:

  • (String)


649
650
651
# File 'lib/google/apis/netapp_v1/classes.rb', line 649

def cache_pre_populate_state
  @cache_pre_populate_state
end

#cifs_change_notify_enabledBoolean Also known as: cifs_change_notify_enabled?

Optional. Flag indicating whether a CIFS change notification is enabled for the FlexCache volume. Corresponds to the JSON property cifsChangeNotifyEnabled

Returns:

  • (Boolean)


655
656
657
# File 'lib/google/apis/netapp_v1/classes.rb', line 655

def cifs_change_notify_enabled
  @cifs_change_notify_enabled
end

#writeback_enabledBoolean Also known as: writeback_enabled?

Optional. Flag indicating whether writeback is enabled for the FlexCache volume. Corresponds to the JSON property writebackEnabled

Returns:

  • (Boolean)


662
663
664
# File 'lib/google/apis/netapp_v1/classes.rb', line 662

def writeback_enabled
  @writeback_enabled
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



670
671
672
673
674
675
# File 'lib/google/apis/netapp_v1/classes.rb', line 670

def update!(**args)
  @cache_pre_populate = args[:cache_pre_populate] if args.key?(:cache_pre_populate)
  @cache_pre_populate_state = args[:cache_pre_populate_state] if args.key?(:cache_pre_populate_state)
  @cifs_change_notify_enabled = args[:cifs_change_notify_enabled] if args.key?(:cifs_change_notify_enabled)
  @writeback_enabled = args[:writeback_enabled] if args.key?(:writeback_enabled)
end