Class: Google::Apis::NetappV1::CloneDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/netapp_v1/classes.rb,
lib/google/apis/netapp_v1/representations.rb,
lib/google/apis/netapp_v1/representations.rb

Overview

Details about a clone volume.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CloneDetails

Returns a new instance of CloneDetails.



863
864
865
# File 'lib/google/apis/netapp_v1/classes.rb', line 863

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#shared_space_gibFixnum

Output only. Shared space in GiB. Determined at volume creation time based on size of source snapshot. Corresponds to the JSON property sharedSpaceGib

Returns:

  • (Fixnum)


848
849
850
# File 'lib/google/apis/netapp_v1/classes.rb', line 848

def shared_space_gib
  @shared_space_gib
end

#source_snapshotString

Output only. Specifies the full resource name of the source snapshot from which this volume was cloned. Format: projects/project/locations/location/ volumes/volume/snapshots/snapshot Corresponds to the JSON property sourceSnapshot

Returns:

  • (String)


855
856
857
# File 'lib/google/apis/netapp_v1/classes.rb', line 855

def source_snapshot
  @source_snapshot
end

#source_volumeString

Output only. Full name of the source volume resource. Format: projects/ project/locations/location/volumes/volume Corresponds to the JSON property sourceVolume

Returns:

  • (String)


861
862
863
# File 'lib/google/apis/netapp_v1/classes.rb', line 861

def source_volume
  @source_volume
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



868
869
870
871
872
# File 'lib/google/apis/netapp_v1/classes.rb', line 868

def update!(**args)
  @shared_space_gib = args[:shared_space_gib] if args.key?(:shared_space_gib)
  @source_snapshot = args[:source_snapshot] if args.key?(:source_snapshot)
  @source_volume = args[:source_volume] if args.key?(:source_volume)
end