Class: Google::Apis::NetappV1::DestinationVolumeParameters

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/netapp_v1/classes.rb,
lib/google/apis/netapp_v1/representations.rb,
lib/google/apis/netapp_v1/representations.rb

Overview

DestinationVolumeParameters specify input parameters used for creating destination volume.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DestinationVolumeParameters

Returns a new instance of DestinationVolumeParameters.



908
909
910
# File 'lib/google/apis/netapp_v1/classes.rb', line 908

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Description for the destination volume. Corresponds to the JSON property description

Returns:

  • (String)


882
883
884
# File 'lib/google/apis/netapp_v1/classes.rb', line 882

def description
  @description
end

#share_nameString

Destination volume's share name. If not specified, source volume's share name will be used. Corresponds to the JSON property shareName

Returns:

  • (String)


888
889
890
# File 'lib/google/apis/netapp_v1/classes.rb', line 888

def share_name
  @share_name
end

#storage_poolString

Required. Existing destination StoragePool name. Corresponds to the JSON property storagePool

Returns:

  • (String)


893
894
895
# File 'lib/google/apis/netapp_v1/classes.rb', line 893

def storage_pool
  @storage_pool
end

#tiering_policyGoogle::Apis::NetappV1::TieringPolicy

Defines tiering policy for the volume. Corresponds to the JSON property tieringPolicy



898
899
900
# File 'lib/google/apis/netapp_v1/classes.rb', line 898

def tiering_policy
  @tiering_policy
end

#volume_idString

Desired destination volume resource id. If not specified, source volume's resource id will be used. This value must start with a lowercase letter followed by up to 62 lowercase letters, numbers, or hyphens, and cannot end with a hyphen. Corresponds to the JSON property volumeId

Returns:

  • (String)


906
907
908
# File 'lib/google/apis/netapp_v1/classes.rb', line 906

def volume_id
  @volume_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



913
914
915
916
917
918
919
# File 'lib/google/apis/netapp_v1/classes.rb', line 913

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @share_name = args[:share_name] if args.key?(:share_name)
  @storage_pool = args[:storage_pool] if args.key?(:storage_pool)
  @tiering_policy = args[:tiering_policy] if args.key?(:tiering_policy)
  @volume_id = args[:volume_id] if args.key?(:volume_id)
end