Class: Google::Apis::NetappV1::EstablishPeeringRequest
- Inherits:
-
Object
- Object
- Google::Apis::NetappV1::EstablishPeeringRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/netapp_v1/classes.rb,
lib/google/apis/netapp_v1/representations.rb,
lib/google/apis/netapp_v1/representations.rb
Overview
EstablishPeeringRequest establishes cluster and svm peerings between the source and the destination replications.
Instance Attribute Summary collapse
-
#peer_cluster_name ⇒ String
Required.
-
#peer_ip_addresses ⇒ Array<String>
Optional.
-
#peer_svm_name ⇒ String
Required.
-
#peer_volume_name ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EstablishPeeringRequest
constructor
A new instance of EstablishPeeringRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EstablishPeeringRequest
Returns a new instance of EstablishPeeringRequest.
963 964 965 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 963 def initialize(**args) update!(**args) end |
Instance Attribute Details
#peer_cluster_name ⇒ String
Required. Name of the user's local source cluster to be peered with the
destination cluster.
Corresponds to the JSON property peerClusterName
944 945 946 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 944 def peer_cluster_name @peer_cluster_name end |
#peer_ip_addresses ⇒ Array<String>
Optional. List of IPv4 ip addresses to be used for peering.
Corresponds to the JSON property peerIpAddresses
949 950 951 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 949 def peer_ip_addresses @peer_ip_addresses end |
#peer_svm_name ⇒ String
Required. Name of the user's local source vserver svm to be peered with the
destination vserver svm.
Corresponds to the JSON property peerSvmName
955 956 957 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 955 def peer_svm_name @peer_svm_name end |
#peer_volume_name ⇒ String
Required. Name of the user's local source volume to be peered with the
destination volume.
Corresponds to the JSON property peerVolumeName
961 962 963 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 961 def peer_volume_name @peer_volume_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
968 969 970 971 972 973 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 968 def update!(**args) @peer_cluster_name = args[:peer_cluster_name] if args.key?(:peer_cluster_name) @peer_ip_addresses = args[:peer_ip_addresses] if args.key?(:peer_ip_addresses) @peer_svm_name = args[:peer_svm_name] if args.key?(:peer_svm_name) @peer_volume_name = args[:peer_volume_name] if args.key?(:peer_volume_name) end |