Class: Google::Apis::NetappV1::EstablishVolumePeeringRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/netapp_v1/classes.rb,
lib/google/apis/netapp_v1/representations.rb,
lib/google/apis/netapp_v1/representations.rb

Overview

EstablishVolumePeeringRequest establishes cluster and svm peerings between the source and destination clusters.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EstablishVolumePeeringRequest

Returns a new instance of EstablishVolumePeeringRequest.



1037
1038
1039
# File 'lib/google/apis/netapp_v1/classes.rb', line 1037

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#peer_cluster_nameString

Required. Name of the user's local source cluster to be peered with the destination cluster. Corresponds to the JSON property peerClusterName

Returns:

  • (String)


1018
1019
1020
# File 'lib/google/apis/netapp_v1/classes.rb', line 1018

def peer_cluster_name
  @peer_cluster_name
end

#peer_ip_addressesArray<String>

Optional. List of IPv4 IP addresses to be used for peering. Corresponds to the JSON property peerIpAddresses

Returns:

  • (Array<String>)


1023
1024
1025
# File 'lib/google/apis/netapp_v1/classes.rb', line 1023

def peer_ip_addresses
  @peer_ip_addresses
end

#peer_svm_nameString

Required. Name of the user's local source vserver svm to be peered with the destination vserver svm. Corresponds to the JSON property peerSvmName

Returns:

  • (String)


1029
1030
1031
# File 'lib/google/apis/netapp_v1/classes.rb', line 1029

def peer_svm_name
  @peer_svm_name
end

#peer_volume_nameString

Required. Name of the user's local source volume to be peered with the destination volume. Corresponds to the JSON property peerVolumeName

Returns:

  • (String)


1035
1036
1037
# File 'lib/google/apis/netapp_v1/classes.rb', line 1035

def peer_volume_name
  @peer_volume_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1042
1043
1044
1045
1046
1047
# File 'lib/google/apis/netapp_v1/classes.rb', line 1042

def update!(**args)
  @peer_cluster_name = args[:peer_cluster_name] if args.key?(:peer_cluster_name)
  @peer_ip_addresses = args[:peer_ip_addresses] if args.key?(:peer_ip_addresses)
  @peer_svm_name = args[:peer_svm_name] if args.key?(:peer_svm_name)
  @peer_volume_name = args[:peer_volume_name] if args.key?(:peer_volume_name)
end