Class: Google::Apis::NetappV1::HostGroup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/netapp_v1/classes.rb,
lib/google/apis/netapp_v1/representations.rb,
lib/google/apis/netapp_v1/representations.rb

Overview

Host group is a collection of hosts that can be used for accessing a Block Volume.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HostGroup

Returns a new instance of HostGroup.



1257
1258
1259
# File 'lib/google/apis/netapp_v1/classes.rb', line 1257

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Create time of the host group. Corresponds to the JSON property createTime

Returns:

  • (String)


1217
1218
1219
# File 'lib/google/apis/netapp_v1/classes.rb', line 1217

def create_time
  @create_time
end

#descriptionString

Optional. Description of the host group. Corresponds to the JSON property description

Returns:

  • (String)


1222
1223
1224
# File 'lib/google/apis/netapp_v1/classes.rb', line 1222

def description
  @description
end

#hostsArray<String>

Required. The list of hosts associated with the host group. Corresponds to the JSON property hosts

Returns:

  • (Array<String>)


1227
1228
1229
# File 'lib/google/apis/netapp_v1/classes.rb', line 1227

def hosts
  @hosts
end

#labelsHash<String,String>

Optional. Labels of the host group. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


1232
1233
1234
# File 'lib/google/apis/netapp_v1/classes.rb', line 1232

def labels
  @labels
end

#nameString

Identifier. The resource name of the host group. Format: projects/ project_number/locations/location_id/hostGroups/host_group_id`. Corresponds to the JSON propertyname`

Returns:

  • (String)


1238
1239
1240
# File 'lib/google/apis/netapp_v1/classes.rb', line 1238

def name
  @name
end

#os_typeString

Required. The OS type of the host group. It indicates the type of operating system used by all of the hosts in the HostGroup. All hosts in a HostGroup must be of the same OS type. This can be set only when creating a HostGroup. Corresponds to the JSON property osType

Returns:

  • (String)


1245
1246
1247
# File 'lib/google/apis/netapp_v1/classes.rb', line 1245

def os_type
  @os_type
end

#stateString

Output only. State of the host group. Corresponds to the JSON property state

Returns:

  • (String)


1250
1251
1252
# File 'lib/google/apis/netapp_v1/classes.rb', line 1250

def state
  @state
end

#typeString

Required. Type of the host group. Corresponds to the JSON property type

Returns:

  • (String)


1255
1256
1257
# File 'lib/google/apis/netapp_v1/classes.rb', line 1255

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1262
1263
1264
1265
1266
1267
1268
1269
1270
1271
# File 'lib/google/apis/netapp_v1/classes.rb', line 1262

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @hosts = args[:hosts] if args.key?(:hosts)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @os_type = args[:os_type] if args.key?(:os_type)
  @state = args[:state] if args.key?(:state)
  @type = args[:type] if args.key?(:type)
end