Class: Google::Apis::NetappV1::KmsConfig
- Inherits:
-
Object
- Object
- Google::Apis::NetappV1::KmsConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/netapp_v1/classes.rb,
lib/google/apis/netapp_v1/representations.rb,
lib/google/apis/netapp_v1/representations.rb
Overview
KmsConfig is the customer-managed encryption key(CMEK) configuration.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#crypto_key_name ⇒ String
Required.
-
#description ⇒ String
Description of the KmsConfig.
-
#instructions ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
Labels as key value pairs Corresponds to the JSON property
labels. -
#name ⇒ String
Identifier.
-
#service_account ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#state_details ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ KmsConfig
constructor
A new instance of KmsConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ KmsConfig
Returns a new instance of KmsConfig.
1490 1491 1492 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1490 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Create time of the KmsConfig.
Corresponds to the JSON property createTime
1444 1445 1446 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1444 def create_time @create_time end |
#crypto_key_name ⇒ String
Required. Customer-managed crypto key resource full name. Format: projects/
project/locations/location/keyRings/key_ring/cryptoKeys/crypto_key`
Corresponds to the JSON propertycryptoKeyName`
1450 1451 1452 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1450 def crypto_key_name @crypto_key_name end |
#description ⇒ String
Description of the KmsConfig.
Corresponds to the JSON property description
1455 1456 1457 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1455 def description @description end |
#instructions ⇒ String
Output only. Instructions to provide the access to the customer provided
encryption key.
Corresponds to the JSON property instructions
1461 1462 1463 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1461 def instructions @instructions end |
#labels ⇒ Hash<String,String>
Labels as key value pairs
Corresponds to the JSON property labels
1466 1467 1468 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1466 def labels @labels end |
#name ⇒ String
Identifier. Name of the KmsConfig. Format: projects/project/locations/
location/kmsConfigs/kms_config`
Corresponds to the JSON propertyname`
1472 1473 1474 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1472 def name @name end |
#service_account ⇒ String
Output only. The Service account which will have access to the customer
provided encryption key.
Corresponds to the JSON property serviceAccount
1478 1479 1480 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1478 def service_account @service_account end |
#state ⇒ String
Output only. State of the KmsConfig.
Corresponds to the JSON property state
1483 1484 1485 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1483 def state @state end |
#state_details ⇒ String
Output only. State details of the KmsConfig.
Corresponds to the JSON property stateDetails
1488 1489 1490 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1488 def state_details @state_details end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1495 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @crypto_key_name = args[:crypto_key_name] if args.key?(:crypto_key_name) @description = args[:description] if args.key?(:description) @instructions = args[:instructions] if args.key?(:instructions) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @service_account = args[:service_account] if args.key?(:service_account) @state = args[:state] if args.key?(:state) @state_details = args[:state_details] if args.key?(:state_details) end |