Class: Google::Apis::NetappV1::LargeCapacityConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/netapp_v1/classes.rb,
lib/google/apis/netapp_v1/representations.rb,
lib/google/apis/netapp_v1/representations.rb

Overview

Configuration for a Large Capacity Volume. A Large Capacity Volume supports sizes ranging from 4.8 TiB to 20 PiB, it is composed of multiple internal constituents, and must be created in a large capacity pool.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LargeCapacityConfig

Returns a new instance of LargeCapacityConfig.



1487
1488
1489
# File 'lib/google/apis/netapp_v1/classes.rb', line 1487

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#constituent_countFixnum

Optional. The number of internal constituents (e.g., FlexVols) for this large volume. The minimum number of constituents is 2. Corresponds to the JSON property constituentCount

Returns:

  • (Fixnum)


1485
1486
1487
# File 'lib/google/apis/netapp_v1/classes.rb', line 1485

def constituent_count
  @constituent_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1492
1493
1494
# File 'lib/google/apis/netapp_v1/classes.rb', line 1492

def update!(**args)
  @constituent_count = args[:constituent_count] if args.key?(:constituent_count)
end