Class: Google::Apis::NetappV1::ListBackupsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/netapp_v1/classes.rb,
lib/google/apis/netapp_v1/representations.rb,
lib/google/apis/netapp_v1/representations.rb

Overview

ListBackupsResponse is the result of ListBackupsRequest.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListBackupsResponse

Returns a new instance of ListBackupsResponse.



1682
1683
1684
# File 'lib/google/apis/netapp_v1/classes.rb', line 1682

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backupsArray<Google::Apis::NetappV1::Backup>

A list of backups in the project. Corresponds to the JSON property backups

Returns:



1669
1670
1671
# File 'lib/google/apis/netapp_v1/classes.rb', line 1669

def backups
  @backups
end

#next_page_tokenString

The token you can use to retrieve the next page of results. Not returned if there are no more results in the list. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1675
1676
1677
# File 'lib/google/apis/netapp_v1/classes.rb', line 1675

def next_page_token
  @next_page_token
end

#unreachableArray<String>

Locations that could not be reached. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


1680
1681
1682
# File 'lib/google/apis/netapp_v1/classes.rb', line 1680

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1687
1688
1689
1690
1691
# File 'lib/google/apis/netapp_v1/classes.rb', line 1687

def update!(**args)
  @backups = args[:backups] if args.key?(:backups)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end