Class: Google::Apis::NetappV1::ListHostGroupsResponse
- Inherits:
-
Object
- Object
- Google::Apis::NetappV1::ListHostGroupsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/netapp_v1/classes.rb,
lib/google/apis/netapp_v1/representations.rb,
lib/google/apis/netapp_v1/representations.rb
Overview
ListHostGroupsResponse is the response to a ListHostGroupsRequest.
Instance Attribute Summary collapse
-
#host_groups ⇒ Array<Google::Apis::NetappV1::HostGroup>
The list of host groups.
-
#next_page_token ⇒ String
A token identifying a page of results the server should return.
-
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListHostGroupsResponse
constructor
A new instance of ListHostGroupsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListHostGroupsResponse
Returns a new instance of ListHostGroupsResponse.
1707 1708 1709 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1707 def initialize(**args) update!(**args) end |
Instance Attribute Details
#host_groups ⇒ Array<Google::Apis::NetappV1::HostGroup>
The list of host groups.
Corresponds to the JSON property hostGroups
1695 1696 1697 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1695 def host_groups @host_groups end |
#next_page_token ⇒ String
A token identifying a page of results the server should return.
Corresponds to the JSON property nextPageToken
1700 1701 1702 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1700 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
1705 1706 1707 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1705 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1712 1713 1714 1715 1716 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1712 def update!(**args) @host_groups = args[:host_groups] if args.key?(:host_groups) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |