Class: Google::Apis::NetappV1::ListQuotaRulesResponse
- Inherits:
-
Object
- Object
- Google::Apis::NetappV1::ListQuotaRulesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/netapp_v1/classes.rb,
lib/google/apis/netapp_v1/representations.rb,
lib/google/apis/netapp_v1/representations.rb
Overview
ListQuotaRulesResponse is the response to a ListQuotaRulesRequest.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token identifying a page of results the server should return.
-
#quota_rules ⇒ Array<Google::Apis::NetappV1::QuotaRule>
List of quota rules Corresponds to the JSON property
quotaRules. -
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListQuotaRulesResponse
constructor
A new instance of ListQuotaRulesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListQuotaRulesResponse
Returns a new instance of ListQuotaRulesResponse.
1828 1829 1830 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1828 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token identifying a page of results the server should return.
Corresponds to the JSON property nextPageToken
1816 1817 1818 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1816 def next_page_token @next_page_token end |
#quota_rules ⇒ Array<Google::Apis::NetappV1::QuotaRule>
List of quota rules
Corresponds to the JSON property quotaRules
1821 1822 1823 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1821 def quota_rules @quota_rules end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
1826 1827 1828 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1826 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1833 1834 1835 1836 1837 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1833 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @quota_rules = args[:quota_rules] if args.key?(:quota_rules) @unreachable = args[:unreachable] if args.key?(:unreachable) end |