Class: Google::Apis::NetappV1::ListReplicationsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/netapp_v1/classes.rb,
lib/google/apis/netapp_v1/representations.rb,
lib/google/apis/netapp_v1/representations.rb

Overview

ListReplicationsResponse is the result of ListReplicationsRequest.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListReplicationsResponse

Returns a new instance of ListReplicationsResponse.



1866
1867
1868
# File 'lib/google/apis/netapp_v1/classes.rb', line 1866

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

The token you can use to retrieve the next page of results. Not returned if there are no more results in the list. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1854
1855
1856
# File 'lib/google/apis/netapp_v1/classes.rb', line 1854

def next_page_token
  @next_page_token
end

#replicationsArray<Google::Apis::NetappV1::Replication>

A list of replications in the project for the specified volume. Corresponds to the JSON property replications



1859
1860
1861
# File 'lib/google/apis/netapp_v1/classes.rb', line 1859

def replications
  @replications
end

#unreachableArray<String>

Locations that could not be reached. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


1864
1865
1866
# File 'lib/google/apis/netapp_v1/classes.rb', line 1864

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1871
1872
1873
1874
1875
# File 'lib/google/apis/netapp_v1/classes.rb', line 1871

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @replications = args[:replications] if args.key?(:replications)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end