Class: Google::Apis::NetappV1::ListSnapshotsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/netapp_v1/classes.rb,
lib/google/apis/netapp_v1/representations.rb,
lib/google/apis/netapp_v1/representations.rb

Overview

ListSnapshotsResponse is the result of ListSnapshotsRequest.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListSnapshotsResponse

Returns a new instance of ListSnapshotsResponse.



1898
1899
1900
# File 'lib/google/apis/netapp_v1/classes.rb', line 1898

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

The token you can use to retrieve the next page of results. Not returned if there are no more results in the list. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1886
1887
1888
# File 'lib/google/apis/netapp_v1/classes.rb', line 1886

def next_page_token
  @next_page_token
end

#snapshotsArray<Google::Apis::NetappV1::Snapshot>

A list of snapshots in the project for the specified volume. Corresponds to the JSON property snapshots



1891
1892
1893
# File 'lib/google/apis/netapp_v1/classes.rb', line 1891

def snapshots
  @snapshots
end

#unreachableArray<String>

Locations that could not be reached. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


1896
1897
1898
# File 'lib/google/apis/netapp_v1/classes.rb', line 1896

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1903
1904
1905
1906
1907
# File 'lib/google/apis/netapp_v1/classes.rb', line 1903

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @snapshots = args[:snapshots] if args.key?(:snapshots)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end