Class: Google::Apis::NetappV1::ListVolumesResponse
- Inherits:
-
Object
- Object
- Google::Apis::NetappV1::ListVolumesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/netapp_v1/classes.rb,
lib/google/apis/netapp_v1/representations.rb,
lib/google/apis/netapp_v1/representations.rb
Overview
Message for response to listing Volumes
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token identifying a page of results the server should return.
-
#unreachable ⇒ Array<String>
Locations that could not be reached.
-
#volumes ⇒ Array<Google::Apis::NetappV1::Volume>
The list of Volume Corresponds to the JSON property
volumes.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListVolumesResponse
constructor
A new instance of ListVolumesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListVolumesResponse
Returns a new instance of ListVolumesResponse.
1954 1955 1956 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1954 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token identifying a page of results the server should return.
Corresponds to the JSON property nextPageToken
1942 1943 1944 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1942 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
1947 1948 1949 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1947 def unreachable @unreachable end |
#volumes ⇒ Array<Google::Apis::NetappV1::Volume>
The list of Volume
Corresponds to the JSON property volumes
1952 1953 1954 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1952 def volumes @volumes end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1959 1960 1961 1962 1963 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1959 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) @volumes = args[:volumes] if args.key?(:volumes) end |