Class: Google::Apis::NetappV1::MonthlySchedule
- Inherits:
-
Object
- Object
- Google::Apis::NetappV1::MonthlySchedule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/netapp_v1/classes.rb,
lib/google/apis/netapp_v1/representations.rb,
lib/google/apis/netapp_v1/representations.rb
Overview
Make a snapshot once a month e.g. at 2nd 04:00, 7th 05:20, 24th 23:50
Instance Attribute Summary collapse
-
#days_of_month ⇒ String
Set the day or days of the month to make a snapshot (1-31).
-
#hour ⇒ Float
Set the hour to start the snapshot (0-23), defaults to midnight (0).
-
#minute ⇒ Float
Set the minute of the hour to start the snapshot (0-59), defaults to the top of the hour (0).
-
#snapshots_to_keep ⇒ Float
The maximum number of Snapshots to keep for the hourly schedule Corresponds to the JSON property
snapshotsToKeep.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MonthlySchedule
constructor
A new instance of MonthlySchedule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MonthlySchedule
Returns a new instance of MonthlySchedule.
2013 2014 2015 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 2013 def initialize(**args) update!(**args) end |
Instance Attribute Details
#days_of_month ⇒ String
Set the day or days of the month to make a snapshot (1-31). Accepts a comma
separated number of days. Defaults to '1'.
Corresponds to the JSON property daysOfMonth
1995 1996 1997 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1995 def days_of_month @days_of_month end |
#hour ⇒ Float
Set the hour to start the snapshot (0-23), defaults to midnight (0).
Corresponds to the JSON property hour
2000 2001 2002 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 2000 def hour @hour end |
#minute ⇒ Float
Set the minute of the hour to start the snapshot (0-59), defaults to the top
of the hour (0).
Corresponds to the JSON property minute
2006 2007 2008 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 2006 def minute @minute end |
#snapshots_to_keep ⇒ Float
The maximum number of Snapshots to keep for the hourly schedule
Corresponds to the JSON property snapshotsToKeep
2011 2012 2013 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 2011 def snapshots_to_keep @snapshots_to_keep end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2018 2019 2020 2021 2022 2023 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 2018 def update!(**args) @days_of_month = args[:days_of_month] if args.key?(:days_of_month) @hour = args[:hour] if args.key?(:hour) @minute = args[:minute] if args.key?(:minute) @snapshots_to_keep = args[:snapshots_to_keep] if args.key?(:snapshots_to_keep) end |