Class: Google::Apis::NetappV1::QuotaRule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/netapp_v1/classes.rb,
lib/google/apis/netapp_v1/representations.rb,
lib/google/apis/netapp_v1/representations.rb

Overview

QuotaRule specifies the maximum disk space a user or group can use within a volume. They can be used for creating default and individual quota rules.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ QuotaRule

Returns a new instance of QuotaRule.



2372
2373
2374
# File 'lib/google/apis/netapp_v1/classes.rb', line 2372

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Create time of the quota rule Corresponds to the JSON property createTime

Returns:

  • (String)


2327
2328
2329
# File 'lib/google/apis/netapp_v1/classes.rb', line 2327

def create_time
  @create_time
end

#descriptionString

Optional. Description of the quota rule Corresponds to the JSON property description

Returns:

  • (String)


2332
2333
2334
# File 'lib/google/apis/netapp_v1/classes.rb', line 2332

def description
  @description
end

#disk_limit_mibFixnum

Required. The maximum allowed disk space in MiB. Corresponds to the JSON property diskLimitMib

Returns:

  • (Fixnum)


2337
2338
2339
# File 'lib/google/apis/netapp_v1/classes.rb', line 2337

def disk_limit_mib
  @disk_limit_mib
end

#labelsHash<String,String>

Optional. Labels of the quota rule Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


2342
2343
2344
# File 'lib/google/apis/netapp_v1/classes.rb', line 2342

def labels
  @labels
end

#nameString

Identifier. The resource name of the quota rule. Format: projects/ project_number/locations/location_id/volumes/volumes/volume_id/quotaRules/ quota_rule_id`. Corresponds to the JSON propertyname`

Returns:

  • (String)


2349
2350
2351
# File 'lib/google/apis/netapp_v1/classes.rb', line 2349

def name
  @name
end

#stateString

Output only. State of the quota rule Corresponds to the JSON property state

Returns:

  • (String)


2354
2355
2356
# File 'lib/google/apis/netapp_v1/classes.rb', line 2354

def state
  @state
end

#state_detailsString

Output only. State details of the quota rule Corresponds to the JSON property stateDetails

Returns:

  • (String)


2359
2360
2361
# File 'lib/google/apis/netapp_v1/classes.rb', line 2359

def state_details
  @state_details
end

#targetString

Optional. The quota rule applies to the specified user or group, identified by a Unix UID/GID, Windows SID, or null for default. Corresponds to the JSON property target

Returns:

  • (String)


2365
2366
2367
# File 'lib/google/apis/netapp_v1/classes.rb', line 2365

def target
  @target
end

#typeString

Required. The type of quota rule. Corresponds to the JSON property type

Returns:

  • (String)


2370
2371
2372
# File 'lib/google/apis/netapp_v1/classes.rb', line 2370

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2377
2378
2379
2380
2381
2382
2383
2384
2385
2386
2387
# File 'lib/google/apis/netapp_v1/classes.rb', line 2377

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @disk_limit_mib = args[:disk_limit_mib] if args.key?(:disk_limit_mib)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
  @state_details = args[:state_details] if args.key?(:state_details)
  @target = args[:target] if args.key?(:target)
  @type = args[:type] if args.key?(:type)
end