Class: Google::Apis::NetappV1::Replication

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/netapp_v1/classes.rb,
lib/google/apis/netapp_v1/representations.rb,
lib/google/apis/netapp_v1/representations.rb

Overview

Replication is a nested resource under Volume, that describes a cross-region replication relationship between 2 volumes in different regions.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Replication

Returns a new instance of Replication.



2488
2489
2490
# File 'lib/google/apis/netapp_v1/classes.rb', line 2488

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cluster_locationString

Optional. Location of the user cluster. Corresponds to the JSON property clusterLocation

Returns:

  • (String)


2392
2393
2394
# File 'lib/google/apis/netapp_v1/classes.rb', line 2392

def cluster_location
  @cluster_location
end

#create_timeString

Output only. Replication create time. Corresponds to the JSON property createTime

Returns:

  • (String)


2397
2398
2399
# File 'lib/google/apis/netapp_v1/classes.rb', line 2397

def create_time
  @create_time
end

#descriptionString

A description about this replication relationship. Corresponds to the JSON property description

Returns:

  • (String)


2402
2403
2404
# File 'lib/google/apis/netapp_v1/classes.rb', line 2402

def description
  @description
end

#destination_volumeString

Output only. Full name of destination volume resource. Example : "projects/ project/locations/location/volumes/volume_id" Corresponds to the JSON property destinationVolume

Returns:

  • (String)


2408
2409
2410
# File 'lib/google/apis/netapp_v1/classes.rb', line 2408

def destination_volume
  @destination_volume
end

#destination_volume_parametersGoogle::Apis::NetappV1::DestinationVolumeParameters

DestinationVolumeParameters specify input parameters used for creating destination volume. Corresponds to the JSON property destinationVolumeParameters



2414
2415
2416
# File 'lib/google/apis/netapp_v1/classes.rb', line 2414

def destination_volume_parameters
  @destination_volume_parameters
end

#healthyBoolean Also known as: healthy?

Output only. Condition of the relationship. Can be one of the following: - true: The replication relationship is healthy. It has not missed the most recent scheduled transfer. - false: The replication relationship is not healthy. It has missed the most recent scheduled transfer. Corresponds to the JSON property healthy

Returns:

  • (Boolean)


2422
2423
2424
# File 'lib/google/apis/netapp_v1/classes.rb', line 2422

def healthy
  @healthy
end

#hybrid_peering_detailsGoogle::Apis::NetappV1::HybridPeeringDetails

HybridPeeringDetails contains details about the hybrid peering. Corresponds to the JSON property hybridPeeringDetails



2428
2429
2430
# File 'lib/google/apis/netapp_v1/classes.rb', line 2428

def hybrid_peering_details
  @hybrid_peering_details
end

#hybrid_replication_typeString

Output only. Type of the hybrid replication. Corresponds to the JSON property hybridReplicationType

Returns:

  • (String)


2433
2434
2435
# File 'lib/google/apis/netapp_v1/classes.rb', line 2433

def hybrid_replication_type
  @hybrid_replication_type
end

#hybrid_replication_user_commandsGoogle::Apis::NetappV1::UserCommands

UserCommands contains the commands to be executed by the customer. Corresponds to the JSON property hybridReplicationUserCommands



2438
2439
2440
# File 'lib/google/apis/netapp_v1/classes.rb', line 2438

def hybrid_replication_user_commands
  @hybrid_replication_user_commands
end

#labelsHash<String,String>

Resource labels to represent user provided metadata. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


2443
2444
2445
# File 'lib/google/apis/netapp_v1/classes.rb', line 2443

def labels
  @labels
end

#mirror_stateString

Output only. Indicates the state of mirroring. Corresponds to the JSON property mirrorState

Returns:

  • (String)


2448
2449
2450
# File 'lib/google/apis/netapp_v1/classes.rb', line 2448

def mirror_state
  @mirror_state
end

#nameString

Identifier. The resource name of the Replication. Format: projects/ project_id/locations/location/volumes/volume_id/replications/ replication_id`. Corresponds to the JSON propertyname`

Returns:

  • (String)


2455
2456
2457
# File 'lib/google/apis/netapp_v1/classes.rb', line 2455

def name
  @name
end

#replication_scheduleString

Required. Indicates the schedule for replication. Corresponds to the JSON property replicationSchedule

Returns:

  • (String)


2460
2461
2462
# File 'lib/google/apis/netapp_v1/classes.rb', line 2460

def replication_schedule
  @replication_schedule
end

#roleString

Output only. Indicates whether this points to source or destination. Corresponds to the JSON property role

Returns:

  • (String)


2465
2466
2467
# File 'lib/google/apis/netapp_v1/classes.rb', line 2465

def role
  @role
end

#source_volumeString

Output only. Full name of source volume resource. Example : "projects/project /locations/location/volumes/volume_id" Corresponds to the JSON property sourceVolume

Returns:

  • (String)


2471
2472
2473
# File 'lib/google/apis/netapp_v1/classes.rb', line 2471

def source_volume
  @source_volume
end

#stateString

Output only. State of the replication. Corresponds to the JSON property state

Returns:

  • (String)


2476
2477
2478
# File 'lib/google/apis/netapp_v1/classes.rb', line 2476

def state
  @state
end

#state_detailsString

Output only. State details of the replication. Corresponds to the JSON property stateDetails

Returns:

  • (String)


2481
2482
2483
# File 'lib/google/apis/netapp_v1/classes.rb', line 2481

def state_details
  @state_details
end

#transfer_statsGoogle::Apis::NetappV1::TransferStats

TransferStats reports all statistics related to replication transfer. Corresponds to the JSON property transferStats



2486
2487
2488
# File 'lib/google/apis/netapp_v1/classes.rb', line 2486

def transfer_stats
  @transfer_stats
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2493
2494
2495
2496
2497
2498
2499
2500
2501
2502
2503
2504
2505
2506
2507
2508
2509
2510
2511
2512
# File 'lib/google/apis/netapp_v1/classes.rb', line 2493

def update!(**args)
  @cluster_location = args[:cluster_location] if args.key?(:cluster_location)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @destination_volume = args[:destination_volume] if args.key?(:destination_volume)
  @destination_volume_parameters = args[:destination_volume_parameters] if args.key?(:destination_volume_parameters)
  @healthy = args[:healthy] if args.key?(:healthy)
  @hybrid_peering_details = args[:hybrid_peering_details] if args.key?(:hybrid_peering_details)
  @hybrid_replication_type = args[:hybrid_replication_type] if args.key?(:hybrid_replication_type)
  @hybrid_replication_user_commands = args[:hybrid_replication_user_commands] if args.key?(:hybrid_replication_user_commands)
  @labels = args[:labels] if args.key?(:labels)
  @mirror_state = args[:mirror_state] if args.key?(:mirror_state)
  @name = args[:name] if args.key?(:name)
  @replication_schedule = args[:replication_schedule] if args.key?(:replication_schedule)
  @role = args[:role] if args.key?(:role)
  @source_volume = args[:source_volume] if args.key?(:source_volume)
  @state = args[:state] if args.key?(:state)
  @state_details = args[:state_details] if args.key?(:state_details)
  @transfer_stats = args[:transfer_stats] if args.key?(:transfer_stats)
end