Class: Google::Apis::NetappV1::RestoreBackupFilesRequest
- Inherits:
-
Object
- Object
- Google::Apis::NetappV1::RestoreBackupFilesRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/netapp_v1/classes.rb,
lib/google/apis/netapp_v1/representations.rb,
lib/google/apis/netapp_v1/representations.rb
Overview
RestoreBackupFilesRequest restores files from a backup to a volume.
Instance Attribute Summary collapse
-
#backup ⇒ String
Required.
-
#file_list ⇒ Array<String>
Required.
-
#restore_destination_path ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RestoreBackupFilesRequest
constructor
A new instance of RestoreBackupFilesRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RestoreBackupFilesRequest
Returns a new instance of RestoreBackupFilesRequest.
2537 2538 2539 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 2537 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backup ⇒ String
Required. The backup resource name, in the format projects/project_id/
locations/location/backupVaults/backup_vault_id/backups/backup_id`
Corresponds to the JSON propertybackup`
2523 2524 2525 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 2523 def backup @backup end |
#file_list ⇒ Array<String>
Required. List of files to be restored, specified by their absolute path in
the source volume.
Corresponds to the JSON property fileList
2529 2530 2531 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 2529 def file_list @file_list end |
#restore_destination_path ⇒ String
Optional. Absolute directory path in the destination volume. This is required
if the file_list is provided.
Corresponds to the JSON property restoreDestinationPath
2535 2536 2537 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 2535 def restore_destination_path @restore_destination_path end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2542 2543 2544 2545 2546 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 2542 def update!(**args) @backup = args[:backup] if args.key?(:backup) @file_list = args[:file_list] if args.key?(:file_list) @restore_destination_path = args[:restore_destination_path] if args.key?(:restore_destination_path) end |