Class: Google::Apis::NetappV1::SplitStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/netapp_v1/classes.rb,
lib/google/apis/netapp_v1/representations.rb,
lib/google/apis/netapp_v1/representations.rb

Overview

Message for SplitStatus.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SplitStatus

Returns a new instance of SplitStatus.



2904
2905
2906
# File 'lib/google/apis/netapp_v1/classes.rb', line 2904

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#progress_percentFixnum

Output only. The estimated progress percentage of the split operation (0-100). This is meaningful primarily when split_state is IN_PROGRESS. Corresponds to the JSON property progressPercent

Returns:

  • (Fixnum)


2890
2891
2892
# File 'lib/google/apis/netapp_v1/classes.rb', line 2890

def progress_percent
  @progress_percent
end

#split_stateString

Output only. The current state of the clone split operation. Corresponds to the JSON property splitState

Returns:

  • (String)


2895
2896
2897
# File 'lib/google/apis/netapp_v1/classes.rb', line 2895

def split_state
  @split_state
end

#state_detailsString

Output only. Human-readable details about the current state. Mostly used for displaying error messages during split failure Examples: "Split in progress", " Error: insufficient capacity". Corresponds to the JSON property stateDetails

Returns:

  • (String)


2902
2903
2904
# File 'lib/google/apis/netapp_v1/classes.rb', line 2902

def state_details
  @state_details
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2909
2910
2911
2912
2913
# File 'lib/google/apis/netapp_v1/classes.rb', line 2909

def update!(**args)
  @progress_percent = args[:progress_percent] if args.key?(:progress_percent)
  @split_state = args[:split_state] if args.key?(:split_state)
  @state_details = args[:state_details] if args.key?(:state_details)
end