Class: Google::Apis::NetappV1::StopReplicationRequest
- Inherits:
-
Object
- Object
- Google::Apis::NetappV1::StopReplicationRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/netapp_v1/classes.rb,
lib/google/apis/netapp_v1/representations.rb,
lib/google/apis/netapp_v1/representations.rb
Overview
StopReplicationRequest stops a replication until resumed.
Instance Attribute Summary collapse
-
#force ⇒ Boolean
(also: #force?)
Indicates whether to stop replication forcefully while data transfer is in progress.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StopReplicationRequest
constructor
A new instance of StopReplicationRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StopReplicationRequest
Returns a new instance of StopReplicationRequest.
2982 2983 2984 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 2982 def initialize(**args) update!(**args) end |
Instance Attribute Details
#force ⇒ Boolean Also known as: force?
Indicates whether to stop replication forcefully while data transfer is in
progress. Warning! if force is true, this will abort any current transfers and
can lead to data loss due to partial transfer. If force is false, stop
replication will fail while data transfer is in progress and you will need to
retry later.
Corresponds to the JSON property force
2979 2980 2981 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 2979 def force @force end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2987 2988 2989 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 2987 def update!(**args) @force = args[:force] if args.key?(:force) end |