Class: Google::Apis::NetappV1::TieringPolicy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/netapp_v1/classes.rb,
lib/google/apis/netapp_v1/representations.rb,
lib/google/apis/netapp_v1/representations.rb

Overview

Defines tiering policy for the volume.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TieringPolicy

Returns a new instance of TieringPolicy.



3229
3230
3231
# File 'lib/google/apis/netapp_v1/classes.rb', line 3229

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cooling_threshold_daysFixnum

Optional. Time in days to mark the volume's data block as cold and make it eligible for tiering, can be range from 2-183. Default is 31. Corresponds to the JSON property coolingThresholdDays

Returns:

  • (Fixnum)


3214
3215
3216
# File 'lib/google/apis/netapp_v1/classes.rb', line 3214

def cooling_threshold_days
  @cooling_threshold_days
end

#hot_tier_bypass_mode_enabledBoolean Also known as: hot_tier_bypass_mode_enabled?

Optional. Flag indicating that the hot tier bypass mode is enabled. Default is false. This is only applicable to Flex service level. Corresponds to the JSON property hotTierBypassModeEnabled

Returns:

  • (Boolean)


3220
3221
3222
# File 'lib/google/apis/netapp_v1/classes.rb', line 3220

def hot_tier_bypass_mode_enabled
  @hot_tier_bypass_mode_enabled
end

#tier_actionString

Optional. Flag indicating if the volume has tiering policy enable/pause. Default is PAUSED. Corresponds to the JSON property tierAction

Returns:

  • (String)


3227
3228
3229
# File 'lib/google/apis/netapp_v1/classes.rb', line 3227

def tier_action
  @tier_action
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3234
3235
3236
3237
3238
# File 'lib/google/apis/netapp_v1/classes.rb', line 3234

def update!(**args)
  @cooling_threshold_days = args[:cooling_threshold_days] if args.key?(:cooling_threshold_days)
  @hot_tier_bypass_mode_enabled = args[:hot_tier_bypass_mode_enabled] if args.key?(:hot_tier_bypass_mode_enabled)
  @tier_action = args[:tier_action] if args.key?(:tier_action)
end