Class: Google::Apis::NetappV1::TransferStats
- Inherits:
-
Object
- Object
- Google::Apis::NetappV1::TransferStats
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/netapp_v1/classes.rb,
lib/google/apis/netapp_v1/representations.rb,
lib/google/apis/netapp_v1/representations.rb
Overview
TransferStats reports all statistics related to replication transfer.
Instance Attribute Summary collapse
-
#lag_duration ⇒ String
Lag duration indicates the duration by which Destination region volume content lags behind the primary region volume content.
-
#last_transfer_bytes ⇒ Fixnum
Last transfer size in bytes.
-
#last_transfer_duration ⇒ String
Time taken during last transfer.
-
#last_transfer_end_time ⇒ String
Time when last transfer completed.
-
#last_transfer_error ⇒ String
A message describing the cause of the last transfer failure.
-
#total_transfer_duration ⇒ String
Cumulative time taken across all transfers for the replication relationship.
-
#transfer_bytes ⇒ Fixnum
Cumulative bytes transferred so far for the replication relationship.
-
#update_time ⇒ String
Time when progress was updated last.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TransferStats
constructor
A new instance of TransferStats.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TransferStats
Returns a new instance of TransferStats.
3345 3346 3347 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 3345 def initialize(**args) update!(**args) end |
Instance Attribute Details
#lag_duration ⇒ String
Lag duration indicates the duration by which Destination region volume content
lags behind the primary region volume content.
Corresponds to the JSON property lagDuration
3308 3309 3310 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 3308 def lag_duration @lag_duration end |
#last_transfer_bytes ⇒ Fixnum
Last transfer size in bytes.
Corresponds to the JSON property lastTransferBytes
3313 3314 3315 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 3313 def last_transfer_bytes @last_transfer_bytes end |
#last_transfer_duration ⇒ String
Time taken during last transfer.
Corresponds to the JSON property lastTransferDuration
3318 3319 3320 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 3318 def last_transfer_duration @last_transfer_duration end |
#last_transfer_end_time ⇒ String
Time when last transfer completed.
Corresponds to the JSON property lastTransferEndTime
3323 3324 3325 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 3323 def last_transfer_end_time @last_transfer_end_time end |
#last_transfer_error ⇒ String
A message describing the cause of the last transfer failure.
Corresponds to the JSON property lastTransferError
3328 3329 3330 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 3328 def last_transfer_error @last_transfer_error end |
#total_transfer_duration ⇒ String
Cumulative time taken across all transfers for the replication relationship.
Corresponds to the JSON property totalTransferDuration
3333 3334 3335 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 3333 def total_transfer_duration @total_transfer_duration end |
#transfer_bytes ⇒ Fixnum
Cumulative bytes transferred so far for the replication relationship.
Corresponds to the JSON property transferBytes
3338 3339 3340 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 3338 def transfer_bytes @transfer_bytes end |
#update_time ⇒ String
Time when progress was updated last.
Corresponds to the JSON property updateTime
3343 3344 3345 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 3343 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3350 3351 3352 3353 3354 3355 3356 3357 3358 3359 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 3350 def update!(**args) @lag_duration = args[:lag_duration] if args.key?(:lag_duration) @last_transfer_bytes = args[:last_transfer_bytes] if args.key?(:last_transfer_bytes) @last_transfer_duration = args[:last_transfer_duration] if args.key?(:last_transfer_duration) @last_transfer_end_time = args[:last_transfer_end_time] if args.key?(:last_transfer_end_time) @last_transfer_error = args[:last_transfer_error] if args.key?(:last_transfer_error) @total_transfer_duration = args[:total_transfer_duration] if args.key?(:total_transfer_duration) @transfer_bytes = args[:transfer_bytes] if args.key?(:transfer_bytes) @update_time = args[:update_time] if args.key?(:update_time) end |