Class: Google::Apis::NetappV1::UpdateBackupConfigRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/netapp_v1/classes.rb,
lib/google/apis/netapp_v1/representations.rb,
lib/google/apis/netapp_v1/representations.rb

Overview

Request message for UpdateBackupConfig

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UpdateBackupConfigRequest

Returns a new instance of UpdateBackupConfigRequest.



3325
3326
3327
# File 'lib/google/apis/netapp_v1/classes.rb', line 3325

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backup_configGoogle::Apis::NetappV1::BackupConfig

BackupConfig contains backup related config on a volume. Corresponds to the JSON property backupConfig



3310
3311
3312
# File 'lib/google/apis/netapp_v1/classes.rb', line 3310

def backup_config
  @backup_config
end

#update_maskString

Required. Field mask is used to specify the fields to be overwritten in the BackupConfig for the Volume. The fields specified in the update_mask are relative to the resource, not the full request. A field will be overwritten if it is in the mask. Corresponds to the JSON property updateMask

Returns:

  • (String)


3318
3319
3320
# File 'lib/google/apis/netapp_v1/classes.rb', line 3318

def update_mask
  @update_mask
end

#volume_uuidString

Required. The UUID of the ONTAP-mode volume. Corresponds to the JSON property volumeUuid

Returns:

  • (String)


3323
3324
3325
# File 'lib/google/apis/netapp_v1/classes.rb', line 3323

def volume_uuid
  @volume_uuid
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3330
3331
3332
3333
3334
# File 'lib/google/apis/netapp_v1/classes.rb', line 3330

def update!(**args)
  @backup_config = args[:backup_config] if args.key?(:backup_config)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
  @volume_uuid = args[:volume_uuid] if args.key?(:volume_uuid)
end