Class: Google::Apis::NetappV1::WeeklySchedule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/netapp_v1/classes.rb,
lib/google/apis/netapp_v1/representations.rb,
lib/google/apis/netapp_v1/representations.rb

Overview

Make a snapshot every week e.g. at Monday 04:00, Wednesday 05:20, Sunday 23:50

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WeeklySchedule

Returns a new instance of WeeklySchedule.



3834
3835
3836
# File 'lib/google/apis/netapp_v1/classes.rb', line 3834

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dayString

Set the day or days of the week to make a snapshot. Accepts a comma separated days of the week. Defaults to 'Sunday'. Corresponds to the JSON property day

Returns:

  • (String)


3816
3817
3818
# File 'lib/google/apis/netapp_v1/classes.rb', line 3816

def day
  @day
end

#hourFloat

Set the hour to start the snapshot (0-23), defaults to midnight (0). Corresponds to the JSON property hour

Returns:

  • (Float)


3821
3822
3823
# File 'lib/google/apis/netapp_v1/classes.rb', line 3821

def hour
  @hour
end

#minuteFloat

Set the minute of the hour to start the snapshot (0-59), defaults to the top of the hour (0). Corresponds to the JSON property minute

Returns:

  • (Float)


3827
3828
3829
# File 'lib/google/apis/netapp_v1/classes.rb', line 3827

def minute
  @minute
end

#snapshots_to_keepFloat

The maximum number of Snapshots to keep for the hourly schedule Corresponds to the JSON property snapshotsToKeep

Returns:

  • (Float)


3832
3833
3834
# File 'lib/google/apis/netapp_v1/classes.rb', line 3832

def snapshots_to_keep
  @snapshots_to_keep
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3839
3840
3841
3842
3843
3844
# File 'lib/google/apis/netapp_v1/classes.rb', line 3839

def update!(**args)
  @day = args[:day] if args.key?(:day)
  @hour = args[:hour] if args.key?(:hour)
  @minute = args[:minute] if args.key?(:minute)
  @snapshots_to_keep = args[:snapshots_to_keep] if args.key?(:snapshots_to_keep)
end