Class: Google::Apis::NetappV1::BackupVault
- Inherits:
-
Object
- Object
- Google::Apis::NetappV1::BackupVault
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/netapp_v1/classes.rb,
lib/google/apis/netapp_v1/representations.rb,
lib/google/apis/netapp_v1/representations.rb
Overview
A NetApp BackupVault.
Instance Attribute Summary collapse
-
#backup_region ⇒ String
Optional.
-
#backup_retention_policy ⇒ Google::Apis::NetappV1::BackupRetentionPolicy
Retention policy for backups in the backup vault Corresponds to the JSON property
backupRetentionPolicy. -
#backup_vault_type ⇒ String
Optional.
-
#backups_crypto_key_version ⇒ String
Output only.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Description of the backup vault.
-
#destination_backup_vault ⇒ String
Output only.
-
#encryption_state ⇒ String
Output only.
-
#kms_config ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
Resource labels to represent user provided metadata.
-
#name ⇒ String
Identifier.
-
#source_backup_vault ⇒ String
Output only.
-
#source_region ⇒ String
Output only.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BackupVault
constructor
A new instance of BackupVault.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BackupVault
Returns a new instance of BackupVault.
592 593 594 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 592 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backup_region ⇒ String
Optional. Region where the backups are stored. Format: projects/project_id/
locations/location`
Corresponds to the JSON propertybackupRegion`
517 518 519 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 517 def backup_region @backup_region end |
#backup_retention_policy ⇒ Google::Apis::NetappV1::BackupRetentionPolicy
Retention policy for backups in the backup vault
Corresponds to the JSON property backupRetentionPolicy
522 523 524 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 522 def backup_retention_policy @backup_retention_policy end |
#backup_vault_type ⇒ String
Optional. Type of backup vault to be created. Default is IN_REGION.
Corresponds to the JSON property backupVaultType
527 528 529 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 527 def backup_vault_type @backup_vault_type end |
#backups_crypto_key_version ⇒ String
Output only. The crypto key version used to encrypt the backup vault. Format:
projects/project/locations/location/keyRings/key_ring/cryptoKeys/
crypto_key/cryptoKeyVersions/crypto_key_version`
Corresponds to the JSON propertybackupsCryptoKeyVersion`
534 535 536 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 534 def backups_crypto_key_version @backups_crypto_key_version end |
#create_time ⇒ String
Output only. Create time of the backup vault.
Corresponds to the JSON property createTime
539 540 541 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 539 def create_time @create_time end |
#description ⇒ String
Description of the backup vault.
Corresponds to the JSON property description
544 545 546 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 544 def description @description end |
#destination_backup_vault ⇒ String
Output only. Name of the Backup vault created in backup region. Format:
projects/project_id/locations/location/backupVaults/backup_vault_id`
Corresponds to the JSON propertydestinationBackupVault`
550 551 552 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 550 def destination_backup_vault @destination_backup_vault end |
#encryption_state ⇒ String
Output only. Field indicating encryption state of CMEK backups.
Corresponds to the JSON property encryptionState
555 556 557 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 555 def encryption_state @encryption_state end |
#kms_config ⇒ String
Optional. Specifies the Key Management System (KMS) configuration to be used
for backup encryption. Format: projects/project/locations/location/
kmsConfigs/kms_config`
Corresponds to the JSON propertykmsConfig`
562 563 564 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 562 def kms_config @kms_config end |
#labels ⇒ Hash<String,String>
Resource labels to represent user provided metadata.
Corresponds to the JSON property labels
567 568 569 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 567 def labels @labels end |
#name ⇒ String
Identifier. The resource name of the backup vault. Format: projects/
project_id/locations/location/backupVaults/backup_vault_id`.
Corresponds to the JSON propertyname`
573 574 575 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 573 def name @name end |
#source_backup_vault ⇒ String
Output only. Name of the Backup vault created in source region. Format:
projects/project_id/locations/location/backupVaults/backup_vault_id`
Corresponds to the JSON propertysourceBackupVault`
579 580 581 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 579 def source_backup_vault @source_backup_vault end |
#source_region ⇒ String
Output only. Region in which the backup vault is created. Format: projects/
project_id/locations/location`
Corresponds to the JSON propertysourceRegion`
585 586 587 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 585 def source_region @source_region end |
#state ⇒ String
Output only. The backup vault state.
Corresponds to the JSON property state
590 591 592 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 590 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 597 def update!(**args) @backup_region = args[:backup_region] if args.key?(:backup_region) @backup_retention_policy = args[:backup_retention_policy] if args.key?(:backup_retention_policy) @backup_vault_type = args[:backup_vault_type] if args.key?(:backup_vault_type) @backups_crypto_key_version = args[:backups_crypto_key_version] if args.key?(:backups_crypto_key_version) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @destination_backup_vault = args[:destination_backup_vault] if args.key?(:destination_backup_vault) @encryption_state = args[:encryption_state] if args.key?(:encryption_state) @kms_config = args[:kms_config] if args.key?(:kms_config) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @source_backup_vault = args[:source_backup_vault] if args.key?(:source_backup_vault) @source_region = args[:source_region] if args.key?(:source_region) @state = args[:state] if args.key?(:state) end |