Class: Google::Apis::NetappV1::BackupVault

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/netapp_v1/classes.rb,
lib/google/apis/netapp_v1/representations.rb,
lib/google/apis/netapp_v1/representations.rb

Overview

A NetApp BackupVault.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackupVault

Returns a new instance of BackupVault.



559
560
561
# File 'lib/google/apis/netapp_v1/classes.rb', line 559

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backup_regionString

Optional. Region where the backups are stored. Format: projects/project_id/ locations/location` Corresponds to the JSON propertybackupRegion`

Returns:

  • (String)


484
485
486
# File 'lib/google/apis/netapp_v1/classes.rb', line 484

def backup_region
  @backup_region
end

#backup_retention_policyGoogle::Apis::NetappV1::BackupRetentionPolicy

Retention policy for backups in the backup vault Corresponds to the JSON property backupRetentionPolicy



489
490
491
# File 'lib/google/apis/netapp_v1/classes.rb', line 489

def backup_retention_policy
  @backup_retention_policy
end

#backup_vault_typeString

Optional. Type of backup vault to be created. Default is IN_REGION. Corresponds to the JSON property backupVaultType

Returns:

  • (String)


494
495
496
# File 'lib/google/apis/netapp_v1/classes.rb', line 494

def backup_vault_type
  @backup_vault_type
end

#backups_crypto_key_versionString

Output only. The crypto key version used to encrypt the backup vault. Format: projects/project/locations/location/keyRings/key_ring/cryptoKeys/ crypto_key/cryptoKeyVersions/crypto_key_version` Corresponds to the JSON propertybackupsCryptoKeyVersion`

Returns:

  • (String)


501
502
503
# File 'lib/google/apis/netapp_v1/classes.rb', line 501

def backups_crypto_key_version
  @backups_crypto_key_version
end

#create_timeString

Output only. Create time of the backup vault. Corresponds to the JSON property createTime

Returns:

  • (String)


506
507
508
# File 'lib/google/apis/netapp_v1/classes.rb', line 506

def create_time
  @create_time
end

#descriptionString

Description of the backup vault. Corresponds to the JSON property description

Returns:

  • (String)


511
512
513
# File 'lib/google/apis/netapp_v1/classes.rb', line 511

def description
  @description
end

#destination_backup_vaultString

Output only. Name of the Backup vault created in backup region. Format: projects/project_id/locations/location/backupVaults/backup_vault_id` Corresponds to the JSON propertydestinationBackupVault`

Returns:

  • (String)


517
518
519
# File 'lib/google/apis/netapp_v1/classes.rb', line 517

def destination_backup_vault
  @destination_backup_vault
end

#encryption_stateString

Output only. Field indicating encryption state of CMEK backups. Corresponds to the JSON property encryptionState

Returns:

  • (String)


522
523
524
# File 'lib/google/apis/netapp_v1/classes.rb', line 522

def encryption_state
  @encryption_state
end

#kms_configString

Optional. Specifies the Key Management System (KMS) configuration to be used for backup encryption. Format: projects/project/locations/location/ kmsConfigs/kms_config` Corresponds to the JSON propertykmsConfig`

Returns:

  • (String)


529
530
531
# File 'lib/google/apis/netapp_v1/classes.rb', line 529

def kms_config
  @kms_config
end

#labelsHash<String,String>

Resource labels to represent user provided metadata. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


534
535
536
# File 'lib/google/apis/netapp_v1/classes.rb', line 534

def labels
  @labels
end

#nameString

Identifier. The resource name of the backup vault. Format: projects/ project_id/locations/location/backupVaults/backup_vault_id`. Corresponds to the JSON propertyname`

Returns:

  • (String)


540
541
542
# File 'lib/google/apis/netapp_v1/classes.rb', line 540

def name
  @name
end

#source_backup_vaultString

Output only. Name of the Backup vault created in source region. Format: projects/project_id/locations/location/backupVaults/backup_vault_id` Corresponds to the JSON propertysourceBackupVault`

Returns:

  • (String)


546
547
548
# File 'lib/google/apis/netapp_v1/classes.rb', line 546

def source_backup_vault
  @source_backup_vault
end

#source_regionString

Output only. Region in which the backup vault is created. Format: projects/ project_id/locations/location` Corresponds to the JSON propertysourceRegion`

Returns:

  • (String)


552
553
554
# File 'lib/google/apis/netapp_v1/classes.rb', line 552

def source_region
  @source_region
end

#stateString

Output only. The backup vault state. Corresponds to the JSON property state

Returns:

  • (String)


557
558
559
# File 'lib/google/apis/netapp_v1/classes.rb', line 557

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
# File 'lib/google/apis/netapp_v1/classes.rb', line 564

def update!(**args)
  @backup_region = args[:backup_region] if args.key?(:backup_region)
  @backup_retention_policy = args[:backup_retention_policy] if args.key?(:backup_retention_policy)
  @backup_vault_type = args[:backup_vault_type] if args.key?(:backup_vault_type)
  @backups_crypto_key_version = args[:backups_crypto_key_version] if args.key?(:backups_crypto_key_version)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @destination_backup_vault = args[:destination_backup_vault] if args.key?(:destination_backup_vault)
  @encryption_state = args[:encryption_state] if args.key?(:encryption_state)
  @kms_config = args[:kms_config] if args.key?(:kms_config)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @source_backup_vault = args[:source_backup_vault] if args.key?(:source_backup_vault)
  @source_region = args[:source_region] if args.key?(:source_region)
  @state = args[:state] if args.key?(:state)
end