Class: Google::Apis::NetappV1::BlockDevice

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/netapp_v1/classes.rb,
lib/google/apis/netapp_v1/representations.rb,
lib/google/apis/netapp_v1/representations.rb

Overview

Block device represents the device(s) which are stored in the block volume.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BlockDevice

Returns a new instance of BlockDevice.



622
623
624
# File 'lib/google/apis/netapp_v1/classes.rb', line 622

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#host_groupsArray<String>

Optional. A list of host groups that identify hosts that can mount the block volume. Format: projects/project_id/locations/location/hostGroups/ host_group_id`This field can be updated after the block device is created. Corresponds to the JSON propertyhostGroups`

Returns:

  • (Array<String>)


591
592
593
# File 'lib/google/apis/netapp_v1/classes.rb', line 591

def host_groups
  @host_groups
end

#identifierString

Output only. Device identifier of the block volume. This represents lun_serial_number for iSCSI volumes. Corresponds to the JSON property identifier

Returns:

  • (String)


597
598
599
# File 'lib/google/apis/netapp_v1/classes.rb', line 597

def identifier
  @identifier
end

#nameString

Optional. User-defined name for the block device, unique within the volume. In case no user input is provided, name will be auto-generated in the backend. The name must meet the following requirements: * Be between 1 and 255 characters long. * Contain only uppercase or lowercase letters (A-Z, a-z), numbers (0-9), and the following special characters: "-", "_", "", "", ".". * Spaces are not allowed. Corresponds to the JSON property name

Returns:

  • (String)


607
608
609
# File 'lib/google/apis/netapp_v1/classes.rb', line 607

def name
  @name
end

#os_typeString

Required. Immutable. The OS type of the volume. This field can't be changed after the block device is created. Corresponds to the JSON property osType

Returns:

  • (String)


613
614
615
# File 'lib/google/apis/netapp_v1/classes.rb', line 613

def os_type
  @os_type
end

#size_gibFixnum

Optional. The size of the block device in GiB. Any value provided for the size_gib field during volume creation is ignored. The block device's size is system-managed and will be set to match the parent Volume's capacity_gib. Corresponds to the JSON property sizeGib

Returns:

  • (Fixnum)


620
621
622
# File 'lib/google/apis/netapp_v1/classes.rb', line 620

def size_gib
  @size_gib
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



627
628
629
630
631
632
633
# File 'lib/google/apis/netapp_v1/classes.rb', line 627

def update!(**args)
  @host_groups = args[:host_groups] if args.key?(:host_groups)
  @identifier = args[:identifier] if args.key?(:identifier)
  @name = args[:name] if args.key?(:name)
  @os_type = args[:os_type] if args.key?(:os_type)
  @size_gib = args[:size_gib] if args.key?(:size_gib)
end