Class: Google::Apis::NetappV1::CacheParameters

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/netapp_v1/classes.rb,
lib/google/apis/netapp_v1/representations.rb,
lib/google/apis/netapp_v1/representations.rb

Overview

Cache Parameters for the volume.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CacheParameters

Returns a new instance of CacheParameters.



740
741
742
# File 'lib/google/apis/netapp_v1/classes.rb', line 740

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cache_configGoogle::Apis::NetappV1::CacheConfig

Configuration of the cache volume. Corresponds to the JSON property cacheConfig



685
686
687
# File 'lib/google/apis/netapp_v1/classes.rb', line 685

def cache_config
  @cache_config
end

#cache_stateString

Output only. State of the cache volume indicating the peering status. Corresponds to the JSON property cacheState

Returns:

  • (String)


690
691
692
# File 'lib/google/apis/netapp_v1/classes.rb', line 690

def cache_state
  @cache_state
end

#commandString

Output only. Copy-paste-able commands to be used on user's ONTAP to accept peering requests. Corresponds to the JSON property command

Returns:

  • (String)


696
697
698
# File 'lib/google/apis/netapp_v1/classes.rb', line 696

def command
  @command
end

#enable_global_file_lockBoolean Also known as: enable_global_file_lock?

Optional. Indicates whether the cache volume has global file lock enabled. Corresponds to the JSON property enableGlobalFileLock

Returns:

  • (Boolean)


701
702
703
# File 'lib/google/apis/netapp_v1/classes.rb', line 701

def enable_global_file_lock
  @enable_global_file_lock
end

#passphraseString

Output only. Temporary passphrase generated to accept cluster peering command. Corresponds to the JSON property passphrase

Returns:

  • (String)


707
708
709
# File 'lib/google/apis/netapp_v1/classes.rb', line 707

def passphrase
  @passphrase
end

#peer_cluster_nameString

Required. Name of the origin volume's ONTAP cluster. Corresponds to the JSON property peerClusterName

Returns:

  • (String)


712
713
714
# File 'lib/google/apis/netapp_v1/classes.rb', line 712

def peer_cluster_name
  @peer_cluster_name
end

#peer_ip_addressesArray<String>

Required. List of IC LIF addresses of the origin volume's ONTAP cluster. Corresponds to the JSON property peerIpAddresses

Returns:

  • (Array<String>)


717
718
719
# File 'lib/google/apis/netapp_v1/classes.rb', line 717

def peer_ip_addresses
  @peer_ip_addresses
end

#peer_svm_nameString

Required. Name of the origin volume's SVM. Corresponds to the JSON property peerSvmName

Returns:

  • (String)


722
723
724
# File 'lib/google/apis/netapp_v1/classes.rb', line 722

def peer_svm_name
  @peer_svm_name
end

#peer_volume_nameString

Required. Name of the origin volume for the cache volume. Corresponds to the JSON property peerVolumeName

Returns:

  • (String)


727
728
729
# File 'lib/google/apis/netapp_v1/classes.rb', line 727

def peer_volume_name
  @peer_volume_name
end

#peering_command_expiry_timeString

Optional. Expiration time for the peering command to be executed on user's ONTAP. Corresponds to the JSON property peeringCommandExpiryTime

Returns:

  • (String)


733
734
735
# File 'lib/google/apis/netapp_v1/classes.rb', line 733

def peering_command_expiry_time
  @peering_command_expiry_time
end

#state_detailsString

Output only. Detailed description of the current cache state. Corresponds to the JSON property stateDetails

Returns:

  • (String)


738
739
740
# File 'lib/google/apis/netapp_v1/classes.rb', line 738

def state_details
  @state_details
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



745
746
747
748
749
750
751
752
753
754
755
756
757
# File 'lib/google/apis/netapp_v1/classes.rb', line 745

def update!(**args)
  @cache_config = args[:cache_config] if args.key?(:cache_config)
  @cache_state = args[:cache_state] if args.key?(:cache_state)
  @command = args[:command] if args.key?(:command)
  @enable_global_file_lock = args[:enable_global_file_lock] if args.key?(:enable_global_file_lock)
  @passphrase = args[:passphrase] if args.key?(:passphrase)
  @peer_cluster_name = args[:peer_cluster_name] if args.key?(:peer_cluster_name)
  @peer_ip_addresses = args[:peer_ip_addresses] if args.key?(:peer_ip_addresses)
  @peer_svm_name = args[:peer_svm_name] if args.key?(:peer_svm_name)
  @peer_volume_name = args[:peer_volume_name] if args.key?(:peer_volume_name)
  @peering_command_expiry_time = args[:peering_command_expiry_time] if args.key?(:peering_command_expiry_time)
  @state_details = args[:state_details] if args.key?(:state_details)
end