Class: Google::Apis::NetappV1::CachePrePopulate
- Inherits:
-
Object
- Object
- Google::Apis::NetappV1::CachePrePopulate
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/netapp_v1/classes.rb,
lib/google/apis/netapp_v1/representations.rb,
lib/google/apis/netapp_v1/representations.rb
Overview
Pre-populate cache volume with data from the origin volume.
Instance Attribute Summary collapse
-
#exclude_path_list ⇒ Array<String>
Optional.
-
#path_list ⇒ Array<String>
Optional.
-
#recursion ⇒ Boolean
(also: #recursion?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CachePrePopulate
constructor
A new instance of CachePrePopulate.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CachePrePopulate
Returns a new instance of CachePrePopulate.
815 816 817 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 815 def initialize(**args) update!(**args) end |
Instance Attribute Details
#exclude_path_list ⇒ Array<String>
Optional. List of directory-paths to be excluded for pre-population for the
FlexCache volume.
Corresponds to the JSON property excludePathList
801 802 803 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 801 def exclude_path_list @exclude_path_list end |
#path_list ⇒ Array<String>
Optional. List of directory-paths to be pre-populated for the FlexCache volume.
Corresponds to the JSON property pathList
806 807 808 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 806 def path_list @path_list end |
#recursion ⇒ Boolean Also known as: recursion?
Optional. Flag indicating whether the directories listed with the path_list
need to be recursively pre-populated.
Corresponds to the JSON property recursion
812 813 814 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 812 def recursion @recursion end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
820 821 822 823 824 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 820 def update!(**args) @exclude_path_list = args[:exclude_path_list] if args.key?(:exclude_path_list) @path_list = args[:path_list] if args.key?(:path_list) @recursion = args[:recursion] if args.key?(:recursion) end |