Class: Google::Apis::NetappV1::CachePrePopulate
- Inherits:
-
Object
- Object
- Google::Apis::NetappV1::CachePrePopulate
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/netapp_v1/classes.rb,
lib/google/apis/netapp_v1/representations.rb,
lib/google/apis/netapp_v1/representations.rb
Overview
Pre-populate cache volume with data from the origin volume.
Instance Attribute Summary collapse
-
#exclude_path_list ⇒ Array<String>
Optional.
-
#path_list ⇒ Array<String>
Optional.
-
#recursion ⇒ Boolean
(also: #recursion?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CachePrePopulate
constructor
A new instance of CachePrePopulate.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CachePrePopulate
Returns a new instance of CachePrePopulate.
782 783 784 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 782 def initialize(**args) update!(**args) end |
Instance Attribute Details
#exclude_path_list ⇒ Array<String>
Optional. List of directory-paths to be excluded for pre-population for the
FlexCache volume.
Corresponds to the JSON property excludePathList
768 769 770 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 768 def exclude_path_list @exclude_path_list end |
#path_list ⇒ Array<String>
Optional. List of directory-paths to be pre-populated for the FlexCache volume.
Corresponds to the JSON property pathList
773 774 775 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 773 def path_list @path_list end |
#recursion ⇒ Boolean Also known as: recursion?
Optional. Flag indicating whether the directories listed with the path_list
need to be recursively pre-populated.
Corresponds to the JSON property recursion
779 780 781 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 779 def recursion @recursion end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
787 788 789 790 791 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 787 def update!(**args) @exclude_path_list = args[:exclude_path_list] if args.key?(:exclude_path_list) @path_list = args[:path_list] if args.key?(:path_list) @recursion = args[:recursion] if args.key?(:recursion) end |