Class: Google::Apis::NetappV1::CloneDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/netapp_v1/classes.rb,
lib/google/apis/netapp_v1/representations.rb,
lib/google/apis/netapp_v1/representations.rb

Overview

Details about a clone volume.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CloneDetails

Returns a new instance of CloneDetails.



830
831
832
# File 'lib/google/apis/netapp_v1/classes.rb', line 830

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#shared_space_gibFixnum

Output only. Shared space in GiB. Determined at volume creation time based on size of source snapshot. Corresponds to the JSON property sharedSpaceGib

Returns:

  • (Fixnum)


815
816
817
# File 'lib/google/apis/netapp_v1/classes.rb', line 815

def shared_space_gib
  @shared_space_gib
end

#source_snapshotString

Output only. Specifies the full resource name of the source snapshot from which this volume was cloned. Format: projects/project/locations/location/ volumes/volume/snapshots/snapshot Corresponds to the JSON property sourceSnapshot

Returns:

  • (String)


822
823
824
# File 'lib/google/apis/netapp_v1/classes.rb', line 822

def source_snapshot
  @source_snapshot
end

#source_volumeString

Output only. Full name of the source volume resource. Format: projects/ project/locations/location/volumes/volume Corresponds to the JSON property sourceVolume

Returns:

  • (String)


828
829
830
# File 'lib/google/apis/netapp_v1/classes.rb', line 828

def source_volume
  @source_volume
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



835
836
837
838
839
# File 'lib/google/apis/netapp_v1/classes.rb', line 835

def update!(**args)
  @shared_space_gib = args[:shared_space_gib] if args.key?(:shared_space_gib)
  @source_snapshot = args[:source_snapshot] if args.key?(:source_snapshot)
  @source_volume = args[:source_volume] if args.key?(:source_volume)
end