Class: Google::Apis::NetappV1::HostGroup
- Inherits:
-
Object
- Object
- Google::Apis::NetappV1::HostGroup
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/netapp_v1/classes.rb,
lib/google/apis/netapp_v1/representations.rb,
lib/google/apis/netapp_v1/representations.rb
Overview
Host group is a collection of hosts that can be used for accessing a Block Volume.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#hosts ⇒ Array<String>
Required.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#os_type ⇒ String
Required.
-
#state ⇒ String
Output only.
-
#type ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HostGroup
constructor
A new instance of HostGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HostGroup
Returns a new instance of HostGroup.
1251 1252 1253 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1251 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Create time of the host group.
Corresponds to the JSON property createTime
1211 1212 1213 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1211 def create_time @create_time end |
#description ⇒ String
Optional. Description of the host group.
Corresponds to the JSON property description
1216 1217 1218 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1216 def description @description end |
#hosts ⇒ Array<String>
Required. The list of hosts associated with the host group.
Corresponds to the JSON property hosts
1221 1222 1223 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1221 def hosts @hosts end |
#labels ⇒ Hash<String,String>
Optional. Labels of the host group.
Corresponds to the JSON property labels
1226 1227 1228 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1226 def labels @labels end |
#name ⇒ String
Identifier. The resource name of the host group. Format: projects/
project_number/locations/location_id/hostGroups/host_group_id`.
Corresponds to the JSON propertyname`
1232 1233 1234 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1232 def name @name end |
#os_type ⇒ String
Required. The OS type of the host group. It indicates the type of operating
system used by all of the hosts in the HostGroup. All hosts in a HostGroup
must be of the same OS type. This can be set only when creating a HostGroup.
Corresponds to the JSON property osType
1239 1240 1241 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1239 def os_type @os_type end |
#state ⇒ String
Output only. State of the host group.
Corresponds to the JSON property state
1244 1245 1246 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1244 def state @state end |
#type ⇒ String
Required. Type of the host group.
Corresponds to the JSON property type
1249 1250 1251 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1249 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1256 1257 1258 1259 1260 1261 1262 1263 1264 1265 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1256 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @hosts = args[:hosts] if args.key?(:hosts) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @os_type = args[:os_type] if args.key?(:os_type) @state = args[:state] if args.key?(:state) @type = args[:type] if args.key?(:type) end |