Class: Google::Apis::NetappV1::HostGroup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/netapp_v1/classes.rb,
lib/google/apis/netapp_v1/representations.rb,
lib/google/apis/netapp_v1/representations.rb

Overview

Host group is a collection of hosts that can be used for accessing a Block Volume.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HostGroup

Returns a new instance of HostGroup.



1218
1219
1220
# File 'lib/google/apis/netapp_v1/classes.rb', line 1218

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Create time of the host group. Corresponds to the JSON property createTime

Returns:

  • (String)


1178
1179
1180
# File 'lib/google/apis/netapp_v1/classes.rb', line 1178

def create_time
  @create_time
end

#descriptionString

Optional. Description of the host group. Corresponds to the JSON property description

Returns:

  • (String)


1183
1184
1185
# File 'lib/google/apis/netapp_v1/classes.rb', line 1183

def description
  @description
end

#hostsArray<String>

Required. The list of hosts associated with the host group. Corresponds to the JSON property hosts

Returns:

  • (Array<String>)


1188
1189
1190
# File 'lib/google/apis/netapp_v1/classes.rb', line 1188

def hosts
  @hosts
end

#labelsHash<String,String>

Optional. Labels of the host group. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


1193
1194
1195
# File 'lib/google/apis/netapp_v1/classes.rb', line 1193

def labels
  @labels
end

#nameString

Identifier. The resource name of the host group. Format: projects/ project_number/locations/location_id/hostGroups/host_group_id`. Corresponds to the JSON propertyname`

Returns:

  • (String)


1199
1200
1201
# File 'lib/google/apis/netapp_v1/classes.rb', line 1199

def name
  @name
end

#os_typeString

Required. The OS type of the host group. It indicates the type of operating system used by all of the hosts in the HostGroup. All hosts in a HostGroup must be of the same OS type. This can be set only when creating a HostGroup. Corresponds to the JSON property osType

Returns:

  • (String)


1206
1207
1208
# File 'lib/google/apis/netapp_v1/classes.rb', line 1206

def os_type
  @os_type
end

#stateString

Output only. State of the host group. Corresponds to the JSON property state

Returns:

  • (String)


1211
1212
1213
# File 'lib/google/apis/netapp_v1/classes.rb', line 1211

def state
  @state
end

#typeString

Required. Type of the host group. Corresponds to the JSON property type

Returns:

  • (String)


1216
1217
1218
# File 'lib/google/apis/netapp_v1/classes.rb', line 1216

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1223
1224
1225
1226
1227
1228
1229
1230
1231
1232
# File 'lib/google/apis/netapp_v1/classes.rb', line 1223

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @hosts = args[:hosts] if args.key?(:hosts)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @os_type = args[:os_type] if args.key?(:os_type)
  @state = args[:state] if args.key?(:state)
  @type = args[:type] if args.key?(:type)
end