Class: Google::Apis::NetappV1::HybridPeeringDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/netapp_v1/classes.rb,
lib/google/apis/netapp_v1/representations.rb,
lib/google/apis/netapp_v1/representations.rb

Overview

HybridPeeringDetails contains details about the hybrid peering.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HybridPeeringDetails

Returns a new instance of HybridPeeringDetails.



1305
1306
1307
# File 'lib/google/apis/netapp_v1/classes.rb', line 1305

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#commandString

Output only. Copy-paste-able commands to be used on user's ONTAP to accept peering requests. Corresponds to the JSON property command

Returns:

  • (String)


1269
1270
1271
# File 'lib/google/apis/netapp_v1/classes.rb', line 1269

def command
  @command
end

#command_expiry_timeString

Output only. Expiration time for the peering command to be executed on user's ONTAP. Corresponds to the JSON property commandExpiryTime

Returns:

  • (String)


1275
1276
1277
# File 'lib/google/apis/netapp_v1/classes.rb', line 1275

def command_expiry_time
  @command_expiry_time
end

#passphraseString

Output only. Temporary passphrase generated to accept cluster peering command. Corresponds to the JSON property passphrase

Returns:

  • (String)


1280
1281
1282
# File 'lib/google/apis/netapp_v1/classes.rb', line 1280

def passphrase
  @passphrase
end

#peer_cluster_nameString

Output only. Name of the user's local source cluster to be peered with the destination cluster. Corresponds to the JSON property peerClusterName

Returns:

  • (String)


1286
1287
1288
# File 'lib/google/apis/netapp_v1/classes.rb', line 1286

def peer_cluster_name
  @peer_cluster_name
end

#peer_svm_nameString

Output only. Name of the user's local source vserver svm to be peered with the destination vserver svm. Corresponds to the JSON property peerSvmName

Returns:

  • (String)


1292
1293
1294
# File 'lib/google/apis/netapp_v1/classes.rb', line 1292

def peer_svm_name
  @peer_svm_name
end

#peer_volume_nameString

Output only. Name of the user's local source volume to be peered with the destination volume. Corresponds to the JSON property peerVolumeName

Returns:

  • (String)


1298
1299
1300
# File 'lib/google/apis/netapp_v1/classes.rb', line 1298

def peer_volume_name
  @peer_volume_name
end

#subnet_ipString

Output only. IP address of the subnet. Corresponds to the JSON property subnetIp

Returns:

  • (String)


1303
1304
1305
# File 'lib/google/apis/netapp_v1/classes.rb', line 1303

def subnet_ip
  @subnet_ip
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1310
1311
1312
1313
1314
1315
1316
1317
1318
# File 'lib/google/apis/netapp_v1/classes.rb', line 1310

def update!(**args)
  @command = args[:command] if args.key?(:command)
  @command_expiry_time = args[:command_expiry_time] if args.key?(:command_expiry_time)
  @passphrase = args[:passphrase] if args.key?(:passphrase)
  @peer_cluster_name = args[:peer_cluster_name] if args.key?(:peer_cluster_name)
  @peer_svm_name = args[:peer_svm_name] if args.key?(:peer_svm_name)
  @peer_volume_name = args[:peer_volume_name] if args.key?(:peer_volume_name)
  @subnet_ip = args[:subnet_ip] if args.key?(:subnet_ip)
end