Class: Google::Apis::NetappV1::HybridReplicationParameters
- Inherits:
-
Object
- Object
- Google::Apis::NetappV1::HybridReplicationParameters
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/netapp_v1/classes.rb,
lib/google/apis/netapp_v1/representations.rb,
lib/google/apis/netapp_v1/representations.rb
Overview
The Hybrid Replication parameters for the volume.
Instance Attribute Summary collapse
-
#cluster_location ⇒ String
Optional.
-
#description ⇒ String
Optional.
-
#hybrid_replication_type ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#large_volume_constituent_count ⇒ Fixnum
Optional.
-
#peer_cluster_name ⇒ String
Required.
-
#peer_ip_addresses ⇒ Array<String>
Required.
-
#peer_svm_name ⇒ String
Required.
-
#peer_volume_name ⇒ String
Required.
-
#replication ⇒ String
Required.
-
#replication_schedule ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HybridReplicationParameters
constructor
A new instance of HybridReplicationParameters.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HybridReplicationParameters
Returns a new instance of HybridReplicationParameters.
1384 1385 1386 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1384 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cluster_location ⇒ String
Optional. Name of source cluster location associated with the Hybrid
replication. This is a free-form field for the display purpose only.
Corresponds to the JSON property clusterLocation
1329 1330 1331 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1329 def cluster_location @cluster_location end |
#description ⇒ String
Optional. Description of the replication.
Corresponds to the JSON property description
1334 1335 1336 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1334 def description @description end |
#hybrid_replication_type ⇒ String
Optional. Type of the hybrid replication.
Corresponds to the JSON property hybridReplicationType
1339 1340 1341 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1339 def hybrid_replication_type @hybrid_replication_type end |
#labels ⇒ Hash<String,String>
Optional. Labels to be added to the replication as the key value pairs.
Corresponds to the JSON property labels
1344 1345 1346 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1344 def labels @labels end |
#large_volume_constituent_count ⇒ Fixnum
Optional. Constituent volume count for large volume.
Corresponds to the JSON property largeVolumeConstituentCount
1349 1350 1351 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1349 def large_volume_constituent_count @large_volume_constituent_count end |
#peer_cluster_name ⇒ String
Required. Name of the user's local source cluster to be peered with the
destination cluster.
Corresponds to the JSON property peerClusterName
1355 1356 1357 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1355 def peer_cluster_name @peer_cluster_name end |
#peer_ip_addresses ⇒ Array<String>
Required. List of node ip addresses to be peered with.
Corresponds to the JSON property peerIpAddresses
1360 1361 1362 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1360 def peer_ip_addresses @peer_ip_addresses end |
#peer_svm_name ⇒ String
Required. Name of the user's local source vserver svm to be peered with the
destination vserver svm.
Corresponds to the JSON property peerSvmName
1366 1367 1368 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1366 def peer_svm_name @peer_svm_name end |
#peer_volume_name ⇒ String
Required. Name of the user's local source volume to be peered with the
destination volume.
Corresponds to the JSON property peerVolumeName
1372 1373 1374 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1372 def peer_volume_name @peer_volume_name end |
#replication ⇒ String
Required. Desired name for the replication of this volume.
Corresponds to the JSON property replication
1377 1378 1379 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1377 def replication @replication end |
#replication_schedule ⇒ String
Optional. Replication Schedule for the replication created.
Corresponds to the JSON property replicationSchedule
1382 1383 1384 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1382 def replication_schedule @replication_schedule end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1389 1390 1391 1392 1393 1394 1395 1396 1397 1398 1399 1400 1401 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1389 def update!(**args) @cluster_location = args[:cluster_location] if args.key?(:cluster_location) @description = args[:description] if args.key?(:description) @hybrid_replication_type = args[:hybrid_replication_type] if args.key?(:hybrid_replication_type) @labels = args[:labels] if args.key?(:labels) @large_volume_constituent_count = args[:large_volume_constituent_count] if args.key?(:large_volume_constituent_count) @peer_cluster_name = args[:peer_cluster_name] if args.key?(:peer_cluster_name) @peer_ip_addresses = args[:peer_ip_addresses] if args.key?(:peer_ip_addresses) @peer_svm_name = args[:peer_svm_name] if args.key?(:peer_svm_name) @peer_volume_name = args[:peer_volume_name] if args.key?(:peer_volume_name) @replication = args[:replication] if args.key?(:replication) @replication_schedule = args[:replication_schedule] if args.key?(:replication_schedule) end |