Class: Google::Apis::NetappV1::KmsConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/netapp_v1/classes.rb,
lib/google/apis/netapp_v1/representations.rb,
lib/google/apis/netapp_v1/representations.rb

Overview

KmsConfig is the customer-managed encryption key(CMEK) configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ KmsConfig

Returns a new instance of KmsConfig.



1457
1458
1459
# File 'lib/google/apis/netapp_v1/classes.rb', line 1457

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Create time of the KmsConfig. Corresponds to the JSON property createTime

Returns:

  • (String)


1411
1412
1413
# File 'lib/google/apis/netapp_v1/classes.rb', line 1411

def create_time
  @create_time
end

#crypto_key_nameString

Required. Customer-managed crypto key resource full name. Format: projects/ project/locations/location/keyRings/key_ring/cryptoKeys/crypto_key` Corresponds to the JSON propertycryptoKeyName`

Returns:

  • (String)


1417
1418
1419
# File 'lib/google/apis/netapp_v1/classes.rb', line 1417

def crypto_key_name
  @crypto_key_name
end

#descriptionString

Description of the KmsConfig. Corresponds to the JSON property description

Returns:

  • (String)


1422
1423
1424
# File 'lib/google/apis/netapp_v1/classes.rb', line 1422

def description
  @description
end

#instructionsString

Output only. Instructions to provide the access to the customer provided encryption key. Corresponds to the JSON property instructions

Returns:

  • (String)


1428
1429
1430
# File 'lib/google/apis/netapp_v1/classes.rb', line 1428

def instructions
  @instructions
end

#labelsHash<String,String>

Labels as key value pairs Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


1433
1434
1435
# File 'lib/google/apis/netapp_v1/classes.rb', line 1433

def labels
  @labels
end

#nameString

Identifier. Name of the KmsConfig. Format: projects/project/locations/ location/kmsConfigs/kms_config` Corresponds to the JSON propertyname`

Returns:

  • (String)


1439
1440
1441
# File 'lib/google/apis/netapp_v1/classes.rb', line 1439

def name
  @name
end

#service_accountString

Output only. The Service account which will have access to the customer provided encryption key. Corresponds to the JSON property serviceAccount

Returns:

  • (String)


1445
1446
1447
# File 'lib/google/apis/netapp_v1/classes.rb', line 1445

def 
  @service_account
end

#stateString

Output only. State of the KmsConfig. Corresponds to the JSON property state

Returns:

  • (String)


1450
1451
1452
# File 'lib/google/apis/netapp_v1/classes.rb', line 1450

def state
  @state
end

#state_detailsString

Output only. State details of the KmsConfig. Corresponds to the JSON property stateDetails

Returns:

  • (String)


1455
1456
1457
# File 'lib/google/apis/netapp_v1/classes.rb', line 1455

def state_details
  @state_details
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1462
1463
1464
1465
1466
1467
1468
1469
1470
1471
1472
# File 'lib/google/apis/netapp_v1/classes.rb', line 1462

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @crypto_key_name = args[:crypto_key_name] if args.key?(:crypto_key_name)
  @description = args[:description] if args.key?(:description)
  @instructions = args[:instructions] if args.key?(:instructions)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @service_account = args[:service_account] if args.key?(:service_account)
  @state = args[:state] if args.key?(:state)
  @state_details = args[:state_details] if args.key?(:state_details)
end