Class: Google::Apis::NetappV1::ListBackupConfigsResponse
- Inherits:
-
Object
- Object
- Google::Apis::NetappV1::ListBackupConfigsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/netapp_v1/classes.rb,
lib/google/apis/netapp_v1/representations.rb,
lib/google/apis/netapp_v1/representations.rb
Overview
Message for response to listing BackupConfigs in an ONTAP StoragePool.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
The token you can use to retrieve the next page of results.
-
#unreachable ⇒ Array<String>
Unordered list.
-
#volume_backup_configs ⇒ Array<Google::Apis::NetappV1::VolumeBackupConfig>
A list of backup configurations for volumes in the pool.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListBackupConfigsResponse
constructor
A new instance of ListBackupConfigsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListBackupConfigsResponse
Returns a new instance of ListBackupConfigsResponse.
1587 1588 1589 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1587 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
The token you can use to retrieve the next page of results. Not returned if
there are no more results in the list.
Corresponds to the JSON property nextPageToken
1575 1576 1577 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1575 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Unordered list. Locations that could not be reached.
Corresponds to the JSON property unreachable
1580 1581 1582 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1580 def unreachable @unreachable end |
#volume_backup_configs ⇒ Array<Google::Apis::NetappV1::VolumeBackupConfig>
A list of backup configurations for volumes in the pool.
Corresponds to the JSON property volumeBackupConfigs
1585 1586 1587 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1585 def volume_backup_configs @volume_backup_configs end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1592 1593 1594 1595 1596 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1592 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) @volume_backup_configs = args[:volume_backup_configs] if args.key?(:volume_backup_configs) end |