Class: Google::Apis::NetappV1::ListBackupConfigsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/netapp_v1/classes.rb,
lib/google/apis/netapp_v1/representations.rb,
lib/google/apis/netapp_v1/representations.rb

Overview

Message for response to listing BackupConfigs in an ONTAP StoragePool.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListBackupConfigsResponse

Returns a new instance of ListBackupConfigsResponse.



1581
1582
1583
# File 'lib/google/apis/netapp_v1/classes.rb', line 1581

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

The token you can use to retrieve the next page of results. Not returned if there are no more results in the list. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1569
1570
1571
# File 'lib/google/apis/netapp_v1/classes.rb', line 1569

def next_page_token
  @next_page_token
end

#unreachableArray<String>

Unordered list. Locations that could not be reached. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


1574
1575
1576
# File 'lib/google/apis/netapp_v1/classes.rb', line 1574

def unreachable
  @unreachable
end

#volume_backup_configsArray<Google::Apis::NetappV1::VolumeBackupConfig>

A list of backup configurations for volumes in the pool. Corresponds to the JSON property volumeBackupConfigs



1579
1580
1581
# File 'lib/google/apis/netapp_v1/classes.rb', line 1579

def volume_backup_configs
  @volume_backup_configs
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1586
1587
1588
1589
1590
# File 'lib/google/apis/netapp_v1/classes.rb', line 1586

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
  @volume_backup_configs = args[:volume_backup_configs] if args.key?(:volume_backup_configs)
end