Class: Google::Apis::NetappV1::ListBackupVaultsResponse
- Inherits:
-
Object
- Object
- Google::Apis::NetappV1::ListBackupVaultsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/netapp_v1/classes.rb,
lib/google/apis/netapp_v1/representations.rb,
lib/google/apis/netapp_v1/representations.rb
Overview
ListBackupVaultsResponse is the result of ListBackupVaultsRequest.
Instance Attribute Summary collapse
-
#backup_vaults ⇒ Array<Google::Apis::NetappV1::BackupVault>
A list of backupVaults in the project for the specified location.
-
#next_page_token ⇒ String
The token you can use to retrieve the next page of results.
-
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListBackupVaultsResponse
constructor
A new instance of ListBackupVaultsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListBackupVaultsResponse
Returns a new instance of ListBackupVaultsResponse.
1650 1651 1652 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1650 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backup_vaults ⇒ Array<Google::Apis::NetappV1::BackupVault>
A list of backupVaults in the project for the specified location.
Corresponds to the JSON property backupVaults
1637 1638 1639 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1637 def backup_vaults @backup_vaults end |
#next_page_token ⇒ String
The token you can use to retrieve the next page of results. Not returned if
there are no more results in the list.
Corresponds to the JSON property nextPageToken
1643 1644 1645 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1643 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
1648 1649 1650 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1648 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1655 1656 1657 1658 1659 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1655 def update!(**args) @backup_vaults = args[:backup_vaults] if args.key?(:backup_vaults) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |