Class: Google::Apis::NetappV1::ListBackupVaultsResponse
- Inherits:
-
Object
- Object
- Google::Apis::NetappV1::ListBackupVaultsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/netapp_v1/classes.rb,
lib/google/apis/netapp_v1/representations.rb,
lib/google/apis/netapp_v1/representations.rb
Overview
ListBackupVaultsResponse is the result of ListBackupVaultsRequest.
Instance Attribute Summary collapse
-
#backup_vaults ⇒ Array<Google::Apis::NetappV1::BackupVault>
A list of backupVaults in the project for the specified location.
-
#next_page_token ⇒ String
The token you can use to retrieve the next page of results.
-
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListBackupVaultsResponse
constructor
A new instance of ListBackupVaultsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListBackupVaultsResponse
Returns a new instance of ListBackupVaultsResponse.
1579 1580 1581 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1579 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backup_vaults ⇒ Array<Google::Apis::NetappV1::BackupVault>
A list of backupVaults in the project for the specified location.
Corresponds to the JSON property backupVaults
1566 1567 1568 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1566 def backup_vaults @backup_vaults end |
#next_page_token ⇒ String
The token you can use to retrieve the next page of results. Not returned if
there are no more results in the list.
Corresponds to the JSON property nextPageToken
1572 1573 1574 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1572 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
1577 1578 1579 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1577 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1584 1585 1586 1587 1588 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1584 def update!(**args) @backup_vaults = args[:backup_vaults] if args.key?(:backup_vaults) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |