Class: Google::Apis::NetappV1::ListBackupsResponse
- Inherits:
-
Object
- Object
- Google::Apis::NetappV1::ListBackupsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/netapp_v1/classes.rb,
lib/google/apis/netapp_v1/representations.rb,
lib/google/apis/netapp_v1/representations.rb
Overview
ListBackupsResponse is the result of ListBackupsRequest.
Instance Attribute Summary collapse
-
#backups ⇒ Array<Google::Apis::NetappV1::Backup>
A list of backups in the project.
-
#next_page_token ⇒ String
The token you can use to retrieve the next page of results.
-
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListBackupsResponse
constructor
A new instance of ListBackupsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListBackupsResponse
Returns a new instance of ListBackupsResponse.
1611 1612 1613 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1611 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backups ⇒ Array<Google::Apis::NetappV1::Backup>
A list of backups in the project.
Corresponds to the JSON property backups
1598 1599 1600 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1598 def backups @backups end |
#next_page_token ⇒ String
The token you can use to retrieve the next page of results. Not returned if
there are no more results in the list.
Corresponds to the JSON property nextPageToken
1604 1605 1606 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1604 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
1609 1610 1611 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1609 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1616 1617 1618 1619 1620 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1616 def update!(**args) @backups = args[:backups] if args.key?(:backups) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |