Class: Google::Apis::NetappV1::ListQuotaRulesResponse
- Inherits:
-
Object
- Object
- Google::Apis::NetappV1::ListQuotaRulesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/netapp_v1/classes.rb,
lib/google/apis/netapp_v1/representations.rb,
lib/google/apis/netapp_v1/representations.rb
Overview
ListQuotaRulesResponse is the response to a ListQuotaRulesRequest.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token identifying a page of results the server should return.
-
#quota_rules ⇒ Array<Google::Apis::NetappV1::QuotaRule>
List of quota rules Corresponds to the JSON property
quotaRules. -
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListQuotaRulesResponse
constructor
A new instance of ListQuotaRulesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListQuotaRulesResponse
Returns a new instance of ListQuotaRulesResponse.
1763 1764 1765 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1763 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token identifying a page of results the server should return.
Corresponds to the JSON property nextPageToken
1751 1752 1753 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1751 def next_page_token @next_page_token end |
#quota_rules ⇒ Array<Google::Apis::NetappV1::QuotaRule>
List of quota rules
Corresponds to the JSON property quotaRules
1756 1757 1758 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1756 def quota_rules @quota_rules end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
1761 1762 1763 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1761 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1768 1769 1770 1771 1772 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1768 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @quota_rules = args[:quota_rules] if args.key?(:quota_rules) @unreachable = args[:unreachable] if args.key?(:unreachable) end |