Class: Google::Apis::NetappV1::ListReplicationsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/netapp_v1/classes.rb,
lib/google/apis/netapp_v1/representations.rb,
lib/google/apis/netapp_v1/representations.rb

Overview

ListReplicationsResponse is the result of ListReplicationsRequest.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListReplicationsResponse

Returns a new instance of ListReplicationsResponse.



1860
1861
1862
# File 'lib/google/apis/netapp_v1/classes.rb', line 1860

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

The token you can use to retrieve the next page of results. Not returned if there are no more results in the list. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1848
1849
1850
# File 'lib/google/apis/netapp_v1/classes.rb', line 1848

def next_page_token
  @next_page_token
end

#replicationsArray<Google::Apis::NetappV1::Replication>

A list of replications in the project for the specified volume. Corresponds to the JSON property replications



1853
1854
1855
# File 'lib/google/apis/netapp_v1/classes.rb', line 1853

def replications
  @replications
end

#unreachableArray<String>

Locations that could not be reached. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


1858
1859
1860
# File 'lib/google/apis/netapp_v1/classes.rb', line 1858

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1865
1866
1867
1868
1869
# File 'lib/google/apis/netapp_v1/classes.rb', line 1865

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @replications = args[:replications] if args.key?(:replications)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end