Class: Google::Apis::NetappV1::ListReplicationsResponse
- Inherits:
-
Object
- Object
- Google::Apis::NetappV1::ListReplicationsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/netapp_v1/classes.rb,
lib/google/apis/netapp_v1/representations.rb,
lib/google/apis/netapp_v1/representations.rb
Overview
ListReplicationsResponse is the result of ListReplicationsRequest.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
The token you can use to retrieve the next page of results.
-
#replications ⇒ Array<Google::Apis::NetappV1::Replication>
A list of replications in the project for the specified volume.
-
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListReplicationsResponse
constructor
A new instance of ListReplicationsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListReplicationsResponse
Returns a new instance of ListReplicationsResponse.
1860 1861 1862 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1860 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
The token you can use to retrieve the next page of results. Not returned if
there are no more results in the list.
Corresponds to the JSON property nextPageToken
1848 1849 1850 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1848 def next_page_token @next_page_token end |
#replications ⇒ Array<Google::Apis::NetappV1::Replication>
A list of replications in the project for the specified volume.
Corresponds to the JSON property replications
1853 1854 1855 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1853 def replications @replications end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
1858 1859 1860 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1858 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1865 1866 1867 1868 1869 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1865 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @replications = args[:replications] if args.key?(:replications) @unreachable = args[:unreachable] if args.key?(:unreachable) end |