Class: Google::Apis::NetappV1::ListReplicationsResponse
- Inherits:
-
Object
- Object
- Google::Apis::NetappV1::ListReplicationsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/netapp_v1/classes.rb,
lib/google/apis/netapp_v1/representations.rb,
lib/google/apis/netapp_v1/representations.rb
Overview
ListReplicationsResponse is the result of ListReplicationsRequest.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
The token you can use to retrieve the next page of results.
-
#replications ⇒ Array<Google::Apis::NetappV1::Replication>
A list of replications in the project for the specified volume.
-
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListReplicationsResponse
constructor
A new instance of ListReplicationsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListReplicationsResponse
Returns a new instance of ListReplicationsResponse.
1795 1796 1797 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1795 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
The token you can use to retrieve the next page of results. Not returned if
there are no more results in the list.
Corresponds to the JSON property nextPageToken
1783 1784 1785 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1783 def next_page_token @next_page_token end |
#replications ⇒ Array<Google::Apis::NetappV1::Replication>
A list of replications in the project for the specified volume.
Corresponds to the JSON property replications
1788 1789 1790 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1788 def replications @replications end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
1793 1794 1795 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1793 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1800 1801 1802 1803 1804 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1800 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @replications = args[:replications] if args.key?(:replications) @unreachable = args[:unreachable] if args.key?(:unreachable) end |