Class: Google::Apis::NetappV1::ListSnapshotsResponse
- Inherits:
-
Object
- Object
- Google::Apis::NetappV1::ListSnapshotsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/netapp_v1/classes.rb,
lib/google/apis/netapp_v1/representations.rb,
lib/google/apis/netapp_v1/representations.rb
Overview
ListSnapshotsResponse is the result of ListSnapshotsRequest.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
The token you can use to retrieve the next page of results.
-
#snapshots ⇒ Array<Google::Apis::NetappV1::Snapshot>
A list of snapshots in the project for the specified volume.
-
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListSnapshotsResponse
constructor
A new instance of ListSnapshotsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListSnapshotsResponse
Returns a new instance of ListSnapshotsResponse.
1892 1893 1894 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1892 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
The token you can use to retrieve the next page of results. Not returned if
there are no more results in the list.
Corresponds to the JSON property nextPageToken
1880 1881 1882 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1880 def next_page_token @next_page_token end |
#snapshots ⇒ Array<Google::Apis::NetappV1::Snapshot>
A list of snapshots in the project for the specified volume.
Corresponds to the JSON property snapshots
1885 1886 1887 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1885 def snapshots @snapshots end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
1890 1891 1892 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1890 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1897 1898 1899 1900 1901 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1897 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @snapshots = args[:snapshots] if args.key?(:snapshots) @unreachable = args[:unreachable] if args.key?(:unreachable) end |