Class: Google::Apis::NetappV1::ListSnapshotsResponse
- Inherits:
-
Object
- Object
- Google::Apis::NetappV1::ListSnapshotsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/netapp_v1/classes.rb,
lib/google/apis/netapp_v1/representations.rb,
lib/google/apis/netapp_v1/representations.rb
Overview
ListSnapshotsResponse is the result of ListSnapshotsRequest.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
The token you can use to retrieve the next page of results.
-
#snapshots ⇒ Array<Google::Apis::NetappV1::Snapshot>
A list of snapshots in the project for the specified volume.
-
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListSnapshotsResponse
constructor
A new instance of ListSnapshotsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListSnapshotsResponse
Returns a new instance of ListSnapshotsResponse.
1827 1828 1829 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1827 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
The token you can use to retrieve the next page of results. Not returned if
there are no more results in the list.
Corresponds to the JSON property nextPageToken
1815 1816 1817 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1815 def next_page_token @next_page_token end |
#snapshots ⇒ Array<Google::Apis::NetappV1::Snapshot>
A list of snapshots in the project for the specified volume.
Corresponds to the JSON property snapshots
1820 1821 1822 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1820 def snapshots @snapshots end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
1825 1826 1827 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1825 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1832 1833 1834 1835 1836 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1832 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @snapshots = args[:snapshots] if args.key?(:snapshots) @unreachable = args[:unreachable] if args.key?(:unreachable) end |