Class: Google::Apis::NetappV1::ListVolumesResponse
- Inherits:
-
Object
- Object
- Google::Apis::NetappV1::ListVolumesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/netapp_v1/classes.rb,
lib/google/apis/netapp_v1/representations.rb,
lib/google/apis/netapp_v1/representations.rb
Overview
Message for response to listing Volumes
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token identifying a page of results the server should return.
-
#unreachable ⇒ Array<String>
Locations that could not be reached.
-
#volumes ⇒ Array<Google::Apis::NetappV1::Volume>
The list of Volume Corresponds to the JSON property
volumes.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListVolumesResponse
constructor
A new instance of ListVolumesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListVolumesResponse
Returns a new instance of ListVolumesResponse.
1889 1890 1891 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1889 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token identifying a page of results the server should return.
Corresponds to the JSON property nextPageToken
1877 1878 1879 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1877 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
1882 1883 1884 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1882 def unreachable @unreachable end |
#volumes ⇒ Array<Google::Apis::NetappV1::Volume>
The list of Volume
Corresponds to the JSON property volumes
1887 1888 1889 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1887 def volumes @volumes end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1894 1895 1896 1897 1898 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 1894 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) @volumes = args[:volumes] if args.key?(:volumes) end |