Class: Google::Apis::NetappV1::QuotaRule
- Inherits:
-
Object
- Object
- Google::Apis::NetappV1::QuotaRule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/netapp_v1/classes.rb,
lib/google/apis/netapp_v1/representations.rb,
lib/google/apis/netapp_v1/representations.rb
Overview
QuotaRule specifies the maximum disk space a user or group can use within a volume. They can be used for creating default and individual quota rules.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#disk_limit_mib ⇒ Fixnum
Required.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#state ⇒ String
Output only.
-
#state_details ⇒ String
Output only.
-
#target ⇒ String
Optional.
-
#type ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ QuotaRule
constructor
A new instance of QuotaRule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ QuotaRule
Returns a new instance of QuotaRule.
2366 2367 2368 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 2366 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Create time of the quota rule
Corresponds to the JSON property createTime
2321 2322 2323 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 2321 def create_time @create_time end |
#description ⇒ String
Optional. Description of the quota rule
Corresponds to the JSON property description
2326 2327 2328 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 2326 def description @description end |
#disk_limit_mib ⇒ Fixnum
Required. The maximum allowed disk space in MiB.
Corresponds to the JSON property diskLimitMib
2331 2332 2333 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 2331 def disk_limit_mib @disk_limit_mib end |
#labels ⇒ Hash<String,String>
Optional. Labels of the quota rule
Corresponds to the JSON property labels
2336 2337 2338 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 2336 def labels @labels end |
#name ⇒ String
Identifier. The resource name of the quota rule. Format: projects/
project_number/locations/location_id/volumes/volumes/volume_id/quotaRules/
quota_rule_id`.
Corresponds to the JSON propertyname`
2343 2344 2345 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 2343 def name @name end |
#state ⇒ String
Output only. State of the quota rule
Corresponds to the JSON property state
2348 2349 2350 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 2348 def state @state end |
#state_details ⇒ String
Output only. State details of the quota rule
Corresponds to the JSON property stateDetails
2353 2354 2355 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 2353 def state_details @state_details end |
#target ⇒ String
Optional. The quota rule applies to the specified user or group, identified by
a Unix UID/GID, Windows SID, or null for default.
Corresponds to the JSON property target
2359 2360 2361 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 2359 def target @target end |
#type ⇒ String
Required. The type of quota rule.
Corresponds to the JSON property type
2364 2365 2366 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 2364 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2371 2372 2373 2374 2375 2376 2377 2378 2379 2380 2381 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 2371 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @disk_limit_mib = args[:disk_limit_mib] if args.key?(:disk_limit_mib) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @state = args[:state] if args.key?(:state) @state_details = args[:state_details] if args.key?(:state_details) @target = args[:target] if args.key?(:target) @type = args[:type] if args.key?(:type) end |