Class: Google::Apis::NetappV1::QuotaRule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/netapp_v1/classes.rb,
lib/google/apis/netapp_v1/representations.rb,
lib/google/apis/netapp_v1/representations.rb

Overview

QuotaRule specifies the maximum disk space a user or group can use within a volume. They can be used for creating default and individual quota rules.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ QuotaRule

Returns a new instance of QuotaRule.



2243
2244
2245
# File 'lib/google/apis/netapp_v1/classes.rb', line 2243

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Create time of the quota rule Corresponds to the JSON property createTime

Returns:

  • (String)


2198
2199
2200
# File 'lib/google/apis/netapp_v1/classes.rb', line 2198

def create_time
  @create_time
end

#descriptionString

Optional. Description of the quota rule Corresponds to the JSON property description

Returns:

  • (String)


2203
2204
2205
# File 'lib/google/apis/netapp_v1/classes.rb', line 2203

def description
  @description
end

#disk_limit_mibFixnum

Required. The maximum allowed disk space in MiB. Corresponds to the JSON property diskLimitMib

Returns:

  • (Fixnum)


2208
2209
2210
# File 'lib/google/apis/netapp_v1/classes.rb', line 2208

def disk_limit_mib
  @disk_limit_mib
end

#labelsHash<String,String>

Optional. Labels of the quota rule Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


2213
2214
2215
# File 'lib/google/apis/netapp_v1/classes.rb', line 2213

def labels
  @labels
end

#nameString

Identifier. The resource name of the quota rule. Format: projects/ project_number/locations/location_id/volumes/volumes/volume_id/quotaRules/ quota_rule_id`. Corresponds to the JSON propertyname`

Returns:

  • (String)


2220
2221
2222
# File 'lib/google/apis/netapp_v1/classes.rb', line 2220

def name
  @name
end

#stateString

Output only. State of the quota rule Corresponds to the JSON property state

Returns:

  • (String)


2225
2226
2227
# File 'lib/google/apis/netapp_v1/classes.rb', line 2225

def state
  @state
end

#state_detailsString

Output only. State details of the quota rule Corresponds to the JSON property stateDetails

Returns:

  • (String)


2230
2231
2232
# File 'lib/google/apis/netapp_v1/classes.rb', line 2230

def state_details
  @state_details
end

#targetString

Optional. The quota rule applies to the specified user or group, identified by a Unix UID/GID, Windows SID, or null for default. Corresponds to the JSON property target

Returns:

  • (String)


2236
2237
2238
# File 'lib/google/apis/netapp_v1/classes.rb', line 2236

def target
  @target
end

#typeString

Required. The type of quota rule. Corresponds to the JSON property type

Returns:

  • (String)


2241
2242
2243
# File 'lib/google/apis/netapp_v1/classes.rb', line 2241

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2248
2249
2250
2251
2252
2253
2254
2255
2256
2257
2258
# File 'lib/google/apis/netapp_v1/classes.rb', line 2248

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @disk_limit_mib = args[:disk_limit_mib] if args.key?(:disk_limit_mib)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
  @state_details = args[:state_details] if args.key?(:state_details)
  @target = args[:target] if args.key?(:target)
  @type = args[:type] if args.key?(:type)
end