Class: Google::Apis::NetappV1::QuotaRule
- Inherits:
-
Object
- Object
- Google::Apis::NetappV1::QuotaRule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/netapp_v1/classes.rb,
lib/google/apis/netapp_v1/representations.rb,
lib/google/apis/netapp_v1/representations.rb
Overview
QuotaRule specifies the maximum disk space a user or group can use within a volume. They can be used for creating default and individual quota rules.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#disk_limit_mib ⇒ Fixnum
Required.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#state ⇒ String
Output only.
-
#state_details ⇒ String
Output only.
-
#target ⇒ String
Optional.
-
#type ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ QuotaRule
constructor
A new instance of QuotaRule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ QuotaRule
Returns a new instance of QuotaRule.
2243 2244 2245 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 2243 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Create time of the quota rule
Corresponds to the JSON property createTime
2198 2199 2200 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 2198 def create_time @create_time end |
#description ⇒ String
Optional. Description of the quota rule
Corresponds to the JSON property description
2203 2204 2205 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 2203 def description @description end |
#disk_limit_mib ⇒ Fixnum
Required. The maximum allowed disk space in MiB.
Corresponds to the JSON property diskLimitMib
2208 2209 2210 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 2208 def disk_limit_mib @disk_limit_mib end |
#labels ⇒ Hash<String,String>
Optional. Labels of the quota rule
Corresponds to the JSON property labels
2213 2214 2215 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 2213 def labels @labels end |
#name ⇒ String
Identifier. The resource name of the quota rule. Format: projects/
project_number/locations/location_id/volumes/volumes/volume_id/quotaRules/
quota_rule_id`.
Corresponds to the JSON propertyname`
2220 2221 2222 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 2220 def name @name end |
#state ⇒ String
Output only. State of the quota rule
Corresponds to the JSON property state
2225 2226 2227 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 2225 def state @state end |
#state_details ⇒ String
Output only. State details of the quota rule
Corresponds to the JSON property stateDetails
2230 2231 2232 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 2230 def state_details @state_details end |
#target ⇒ String
Optional. The quota rule applies to the specified user or group, identified by
a Unix UID/GID, Windows SID, or null for default.
Corresponds to the JSON property target
2236 2237 2238 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 2236 def target @target end |
#type ⇒ String
Required. The type of quota rule.
Corresponds to the JSON property type
2241 2242 2243 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 2241 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2248 2249 2250 2251 2252 2253 2254 2255 2256 2257 2258 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 2248 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @disk_limit_mib = args[:disk_limit_mib] if args.key?(:disk_limit_mib) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @state = args[:state] if args.key?(:state) @state_details = args[:state_details] if args.key?(:state_details) @target = args[:target] if args.key?(:target) @type = args[:type] if args.key?(:type) end |