Class: Google::Apis::NetappV1::RestoreBackupFilesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/netapp_v1/classes.rb,
lib/google/apis/netapp_v1/representations.rb,
lib/google/apis/netapp_v1/representations.rb

Overview

RestoreBackupFilesRequest restores files from a backup to a volume.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RestoreBackupFilesRequest

Returns a new instance of RestoreBackupFilesRequest.



2414
2415
2416
# File 'lib/google/apis/netapp_v1/classes.rb', line 2414

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backupString

Required. The backup resource name, in the format projects/project_id/ locations/location/backupVaults/backup_vault_id/backups/backup_id` Corresponds to the JSON propertybackup`

Returns:

  • (String)


2400
2401
2402
# File 'lib/google/apis/netapp_v1/classes.rb', line 2400

def backup
  @backup
end

#file_listArray<String>

Required. List of files to be restored, specified by their absolute path in the source volume. Corresponds to the JSON property fileList

Returns:

  • (Array<String>)


2406
2407
2408
# File 'lib/google/apis/netapp_v1/classes.rb', line 2406

def file_list
  @file_list
end

#restore_destination_pathString

Optional. Absolute directory path in the destination volume. This is required if the file_list is provided. Corresponds to the JSON property restoreDestinationPath

Returns:

  • (String)


2412
2413
2414
# File 'lib/google/apis/netapp_v1/classes.rb', line 2412

def restore_destination_path
  @restore_destination_path
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2419
2420
2421
2422
2423
# File 'lib/google/apis/netapp_v1/classes.rb', line 2419

def update!(**args)
  @backup = args[:backup] if args.key?(:backup)
  @file_list = args[:file_list] if args.key?(:file_list)
  @restore_destination_path = args[:restore_destination_path] if args.key?(:restore_destination_path)
end