Class: Google::Apis::NetappV1::SimpleExportPolicyRule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/netapp_v1/classes.rb,
lib/google/apis/netapp_v1/representations.rb,
lib/google/apis/netapp_v1/representations.rb

Overview

An export policy rule describing various export options.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SimpleExportPolicyRule

Returns a new instance of SimpleExportPolicyRule.



2746
2747
2748
# File 'lib/google/apis/netapp_v1/classes.rb', line 2746

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#access_typeString

Access type (ReadWrite, ReadOnly, None) Corresponds to the JSON property accessType

Returns:

  • (String)


2658
2659
2660
# File 'lib/google/apis/netapp_v1/classes.rb', line 2658

def access_type
  @access_type
end

#allowed_clientsString

Comma separated list of allowed clients IP addresses Corresponds to the JSON property allowedClients

Returns:

  • (String)


2663
2664
2665
# File 'lib/google/apis/netapp_v1/classes.rb', line 2663

def allowed_clients
  @allowed_clients
end

#anon_uidFixnum

Optional. An integer representing the anonymous user ID. Range is 0 to 4294967295. Required when squash_mode is ROOT_SQUASH or ALL_SQUASH. Corresponds to the JSON property anonUid

Returns:

  • (Fixnum)


2669
2670
2671
# File 'lib/google/apis/netapp_v1/classes.rb', line 2669

def anon_uid
  @anon_uid
end

#has_root_accessString

Whether Unix root access will be granted. Corresponds to the JSON property hasRootAccess

Returns:

  • (String)


2674
2675
2676
# File 'lib/google/apis/netapp_v1/classes.rb', line 2674

def has_root_access
  @has_root_access
end

#kerberos5_read_onlyBoolean Also known as: kerberos5_read_only?

If enabled (true) the rule defines a read only access for clients matching the 'allowedClients' specification. It enables nfs clients to mount using ' authentication' kerberos security mode. Corresponds to the JSON property kerberos5ReadOnly

Returns:

  • (Boolean)


2681
2682
2683
# File 'lib/google/apis/netapp_v1/classes.rb', line 2681

def kerberos5_read_only
  @kerberos5_read_only
end

#kerberos5_read_writeBoolean Also known as: kerberos5_read_write?

If enabled (true) the rule defines read and write access for clients matching the 'allowedClients' specification. It enables nfs clients to mount using ' authentication' kerberos security mode. The 'kerberos5ReadOnly' value be ignored if this is enabled. Corresponds to the JSON property kerberos5ReadWrite

Returns:

  • (Boolean)


2690
2691
2692
# File 'lib/google/apis/netapp_v1/classes.rb', line 2690

def kerberos5_read_write
  @kerberos5_read_write
end

#kerberos5i_read_onlyBoolean Also known as: kerberos5i_read_only?

If enabled (true) the rule defines a read only access for clients matching the 'allowedClients' specification. It enables nfs clients to mount using ' integrity' kerberos security mode. Corresponds to the JSON property kerberos5iReadOnly

Returns:

  • (Boolean)


2698
2699
2700
# File 'lib/google/apis/netapp_v1/classes.rb', line 2698

def kerberos5i_read_only
  @kerberos5i_read_only
end

#kerberos5i_read_writeBoolean Also known as: kerberos5i_read_write?

If enabled (true) the rule defines read and write access for clients matching the 'allowedClients' specification. It enables nfs clients to mount using ' integrity' kerberos security mode. The 'kerberos5iReadOnly' value be ignored if this is enabled. Corresponds to the JSON property kerberos5iReadWrite

Returns:

  • (Boolean)


2707
2708
2709
# File 'lib/google/apis/netapp_v1/classes.rb', line 2707

def kerberos5i_read_write
  @kerberos5i_read_write
end

#kerberos5p_read_onlyBoolean Also known as: kerberos5p_read_only?

If enabled (true) the rule defines a read only access for clients matching the 'allowedClients' specification. It enables nfs clients to mount using 'privacy' kerberos security mode. Corresponds to the JSON property kerberos5pReadOnly

Returns:

  • (Boolean)


2715
2716
2717
# File 'lib/google/apis/netapp_v1/classes.rb', line 2715

def kerberos5p_read_only
  @kerberos5p_read_only
end

#kerberos5p_read_writeBoolean Also known as: kerberos5p_read_write?

If enabled (true) the rule defines read and write access for clients matching the 'allowedClients' specification. It enables nfs clients to mount using ' privacy' kerberos security mode. The 'kerberos5pReadOnly' value be ignored if this is enabled. Corresponds to the JSON property kerberos5pReadWrite

Returns:

  • (Boolean)


2724
2725
2726
# File 'lib/google/apis/netapp_v1/classes.rb', line 2724

def kerberos5p_read_write
  @kerberos5p_read_write
end

#nfsv3Boolean Also known as: nfsv3?

NFS V3 protocol. Corresponds to the JSON property nfsv3

Returns:

  • (Boolean)


2730
2731
2732
# File 'lib/google/apis/netapp_v1/classes.rb', line 2730

def nfsv3
  @nfsv3
end

#nfsv4Boolean Also known as: nfsv4?

NFS V4 protocol. Corresponds to the JSON property nfsv4

Returns:

  • (Boolean)


2736
2737
2738
# File 'lib/google/apis/netapp_v1/classes.rb', line 2736

def nfsv4
  @nfsv4
end

#squash_modeString

Optional. Defines how user identity squashing is applied for this export rule. This field is the preferred way to configure squashing behavior and takes precedence over has_root_access if both are provided. Corresponds to the JSON property squashMode

Returns:

  • (String)


2744
2745
2746
# File 'lib/google/apis/netapp_v1/classes.rb', line 2744

def squash_mode
  @squash_mode
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2751
2752
2753
2754
2755
2756
2757
2758
2759
2760
2761
2762
2763
2764
2765
# File 'lib/google/apis/netapp_v1/classes.rb', line 2751

def update!(**args)
  @access_type = args[:access_type] if args.key?(:access_type)
  @allowed_clients = args[:allowed_clients] if args.key?(:allowed_clients)
  @anon_uid = args[:anon_uid] if args.key?(:anon_uid)
  @has_root_access = args[:has_root_access] if args.key?(:has_root_access)
  @kerberos5_read_only = args[:kerberos5_read_only] if args.key?(:kerberos5_read_only)
  @kerberos5_read_write = args[:kerberos5_read_write] if args.key?(:kerberos5_read_write)
  @kerberos5i_read_only = args[:kerberos5i_read_only] if args.key?(:kerberos5i_read_only)
  @kerberos5i_read_write = args[:kerberos5i_read_write] if args.key?(:kerberos5i_read_write)
  @kerberos5p_read_only = args[:kerberos5p_read_only] if args.key?(:kerberos5p_read_only)
  @kerberos5p_read_write = args[:kerberos5p_read_write] if args.key?(:kerberos5p_read_write)
  @nfsv3 = args[:nfsv3] if args.key?(:nfsv3)
  @nfsv4 = args[:nfsv4] if args.key?(:nfsv4)
  @squash_mode = args[:squash_mode] if args.key?(:squash_mode)
end