Class: Google::Apis::NetappV1::SimpleExportPolicyRule
- Inherits:
-
Object
- Object
- Google::Apis::NetappV1::SimpleExportPolicyRule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/netapp_v1/classes.rb,
lib/google/apis/netapp_v1/representations.rb,
lib/google/apis/netapp_v1/representations.rb
Overview
An export policy rule describing various export options.
Instance Attribute Summary collapse
-
#access_type ⇒ String
Access type (ReadWrite, ReadOnly, None) Corresponds to the JSON property
accessType. -
#allowed_clients ⇒ String
Comma separated list of allowed clients IP addresses Corresponds to the JSON property
allowedClients. -
#anon_uid ⇒ Fixnum
Optional.
-
#has_root_access ⇒ String
Whether Unix root access will be granted.
-
#kerberos5_read_only ⇒ Boolean
(also: #kerberos5_read_only?)
If enabled (true) the rule defines a read only access for clients matching the 'allowedClients' specification.
-
#kerberos5_read_write ⇒ Boolean
(also: #kerberos5_read_write?)
If enabled (true) the rule defines read and write access for clients matching the 'allowedClients' specification.
-
#kerberos5i_read_only ⇒ Boolean
(also: #kerberos5i_read_only?)
If enabled (true) the rule defines a read only access for clients matching the 'allowedClients' specification.
-
#kerberos5i_read_write ⇒ Boolean
(also: #kerberos5i_read_write?)
If enabled (true) the rule defines read and write access for clients matching the 'allowedClients' specification.
-
#kerberos5p_read_only ⇒ Boolean
(also: #kerberos5p_read_only?)
If enabled (true) the rule defines a read only access for clients matching the 'allowedClients' specification.
-
#kerberos5p_read_write ⇒ Boolean
(also: #kerberos5p_read_write?)
If enabled (true) the rule defines read and write access for clients matching the 'allowedClients' specification.
-
#nfsv3 ⇒ Boolean
(also: #nfsv3?)
NFS V3 protocol.
-
#nfsv4 ⇒ Boolean
(also: #nfsv4?)
NFS V4 protocol.
-
#squash_mode ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SimpleExportPolicyRule
constructor
A new instance of SimpleExportPolicyRule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SimpleExportPolicyRule
Returns a new instance of SimpleExportPolicyRule.
2598 2599 2600 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 2598 def initialize(**args) update!(**args) end |
Instance Attribute Details
#access_type ⇒ String
Access type (ReadWrite, ReadOnly, None)
Corresponds to the JSON property accessType
2510 2511 2512 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 2510 def access_type @access_type end |
#allowed_clients ⇒ String
Comma separated list of allowed clients IP addresses
Corresponds to the JSON property allowedClients
2515 2516 2517 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 2515 def allowed_clients @allowed_clients end |
#anon_uid ⇒ Fixnum
Optional. An integer representing the anonymous user ID. Range is 0 to
4294967295. Required when squash_mode is ROOT_SQUASH or ALL_SQUASH.
Corresponds to the JSON property anonUid
2521 2522 2523 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 2521 def anon_uid @anon_uid end |
#has_root_access ⇒ String
Whether Unix root access will be granted.
Corresponds to the JSON property hasRootAccess
2526 2527 2528 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 2526 def has_root_access @has_root_access end |
#kerberos5_read_only ⇒ Boolean Also known as: kerberos5_read_only?
If enabled (true) the rule defines a read only access for clients matching the
'allowedClients' specification. It enables nfs clients to mount using '
authentication' kerberos security mode.
Corresponds to the JSON property kerberos5ReadOnly
2533 2534 2535 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 2533 def kerberos5_read_only @kerberos5_read_only end |
#kerberos5_read_write ⇒ Boolean Also known as: kerberos5_read_write?
If enabled (true) the rule defines read and write access for clients matching
the 'allowedClients' specification. It enables nfs clients to mount using '
authentication' kerberos security mode. The 'kerberos5ReadOnly' value be
ignored if this is enabled.
Corresponds to the JSON property kerberos5ReadWrite
2542 2543 2544 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 2542 def kerberos5_read_write @kerberos5_read_write end |
#kerberos5i_read_only ⇒ Boolean Also known as: kerberos5i_read_only?
If enabled (true) the rule defines a read only access for clients matching the
'allowedClients' specification. It enables nfs clients to mount using '
integrity' kerberos security mode.
Corresponds to the JSON property kerberos5iReadOnly
2550 2551 2552 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 2550 def kerberos5i_read_only @kerberos5i_read_only end |
#kerberos5i_read_write ⇒ Boolean Also known as: kerberos5i_read_write?
If enabled (true) the rule defines read and write access for clients matching
the 'allowedClients' specification. It enables nfs clients to mount using '
integrity' kerberos security mode. The 'kerberos5iReadOnly' value be ignored
if this is enabled.
Corresponds to the JSON property kerberos5iReadWrite
2559 2560 2561 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 2559 def kerberos5i_read_write @kerberos5i_read_write end |
#kerberos5p_read_only ⇒ Boolean Also known as: kerberos5p_read_only?
If enabled (true) the rule defines a read only access for clients matching the
'allowedClients' specification. It enables nfs clients to mount using 'privacy'
kerberos security mode.
Corresponds to the JSON property kerberos5pReadOnly
2567 2568 2569 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 2567 def kerberos5p_read_only @kerberos5p_read_only end |
#kerberos5p_read_write ⇒ Boolean Also known as: kerberos5p_read_write?
If enabled (true) the rule defines read and write access for clients matching
the 'allowedClients' specification. It enables nfs clients to mount using '
privacy' kerberos security mode. The 'kerberos5pReadOnly' value be ignored if
this is enabled.
Corresponds to the JSON property kerberos5pReadWrite
2576 2577 2578 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 2576 def kerberos5p_read_write @kerberos5p_read_write end |
#nfsv3 ⇒ Boolean Also known as: nfsv3?
NFS V3 protocol.
Corresponds to the JSON property nfsv3
2582 2583 2584 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 2582 def nfsv3 @nfsv3 end |
#nfsv4 ⇒ Boolean Also known as: nfsv4?
NFS V4 protocol.
Corresponds to the JSON property nfsv4
2588 2589 2590 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 2588 def nfsv4 @nfsv4 end |
#squash_mode ⇒ String
Optional. Defines how user identity squashing is applied for this export rule.
This field is the preferred way to configure squashing behavior and takes
precedence over has_root_access if both are provided.
Corresponds to the JSON property squashMode
2596 2597 2598 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 2596 def squash_mode @squash_mode end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2603 2604 2605 2606 2607 2608 2609 2610 2611 2612 2613 2614 2615 2616 2617 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 2603 def update!(**args) @access_type = args[:access_type] if args.key?(:access_type) @allowed_clients = args[:allowed_clients] if args.key?(:allowed_clients) @anon_uid = args[:anon_uid] if args.key?(:anon_uid) @has_root_access = args[:has_root_access] if args.key?(:has_root_access) @kerberos5_read_only = args[:kerberos5_read_only] if args.key?(:kerberos5_read_only) @kerberos5_read_write = args[:kerberos5_read_write] if args.key?(:kerberos5_read_write) @kerberos5i_read_only = args[:kerberos5i_read_only] if args.key?(:kerberos5i_read_only) @kerberos5i_read_write = args[:kerberos5i_read_write] if args.key?(:kerberos5i_read_write) @kerberos5p_read_only = args[:kerberos5p_read_only] if args.key?(:kerberos5p_read_only) @kerberos5p_read_write = args[:kerberos5p_read_write] if args.key?(:kerberos5p_read_write) @nfsv3 = args[:nfsv3] if args.key?(:nfsv3) @nfsv4 = args[:nfsv4] if args.key?(:nfsv4) @squash_mode = args[:squash_mode] if args.key?(:squash_mode) end |