Class: Google::Apis::NetappV1::TieringPolicy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/netapp_v1/classes.rb,
lib/google/apis/netapp_v1/representations.rb,
lib/google/apis/netapp_v1/representations.rb

Overview

Defines tiering policy for the volume.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TieringPolicy

Returns a new instance of TieringPolicy.



3081
3082
3083
# File 'lib/google/apis/netapp_v1/classes.rb', line 3081

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cooling_threshold_daysFixnum

Optional. Time in days to mark the volume's data block as cold and make it eligible for tiering, can be range from 2-183. Default is 31. Corresponds to the JSON property coolingThresholdDays

Returns:

  • (Fixnum)


3066
3067
3068
# File 'lib/google/apis/netapp_v1/classes.rb', line 3066

def cooling_threshold_days
  @cooling_threshold_days
end

#hot_tier_bypass_mode_enabledBoolean Also known as: hot_tier_bypass_mode_enabled?

Optional. Flag indicating that the hot tier bypass mode is enabled. Default is false. This is only applicable to Flex service level. Corresponds to the JSON property hotTierBypassModeEnabled

Returns:

  • (Boolean)


3072
3073
3074
# File 'lib/google/apis/netapp_v1/classes.rb', line 3072

def hot_tier_bypass_mode_enabled
  @hot_tier_bypass_mode_enabled
end

#tier_actionString

Optional. Flag indicating if the volume has tiering policy enable/pause. Default is PAUSED. Corresponds to the JSON property tierAction

Returns:

  • (String)


3079
3080
3081
# File 'lib/google/apis/netapp_v1/classes.rb', line 3079

def tier_action
  @tier_action
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3086
3087
3088
3089
3090
# File 'lib/google/apis/netapp_v1/classes.rb', line 3086

def update!(**args)
  @cooling_threshold_days = args[:cooling_threshold_days] if args.key?(:cooling_threshold_days)
  @hot_tier_bypass_mode_enabled = args[:hot_tier_bypass_mode_enabled] if args.key?(:hot_tier_bypass_mode_enabled)
  @tier_action = args[:tier_action] if args.key?(:tier_action)
end