Class: Google::Apis::NetappV1::TransferStats
- Inherits:
-
Object
- Object
- Google::Apis::NetappV1::TransferStats
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/netapp_v1/classes.rb,
lib/google/apis/netapp_v1/representations.rb,
lib/google/apis/netapp_v1/representations.rb
Overview
TransferStats reports all statistics related to replication transfer.
Instance Attribute Summary collapse
-
#lag_duration ⇒ String
Lag duration indicates the duration by which Destination region volume content lags behind the primary region volume content.
-
#last_transfer_bytes ⇒ Fixnum
Last transfer size in bytes.
-
#last_transfer_duration ⇒ String
Time taken during last transfer.
-
#last_transfer_end_time ⇒ String
Time when last transfer completed.
-
#last_transfer_error ⇒ String
A message describing the cause of the last transfer failure.
-
#total_transfer_duration ⇒ String
Cumulative time taken across all transfers for the replication relationship.
-
#transfer_bytes ⇒ Fixnum
Cumulative bytes transferred so far for the replication relationship.
-
#update_time ⇒ String
Time when progress was updated last.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TransferStats
constructor
A new instance of TransferStats.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TransferStats
Returns a new instance of TransferStats.
3286 3287 3288 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 3286 def initialize(**args) update!(**args) end |
Instance Attribute Details
#lag_duration ⇒ String
Lag duration indicates the duration by which Destination region volume content
lags behind the primary region volume content.
Corresponds to the JSON property lagDuration
3249 3250 3251 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 3249 def lag_duration @lag_duration end |
#last_transfer_bytes ⇒ Fixnum
Last transfer size in bytes.
Corresponds to the JSON property lastTransferBytes
3254 3255 3256 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 3254 def last_transfer_bytes @last_transfer_bytes end |
#last_transfer_duration ⇒ String
Time taken during last transfer.
Corresponds to the JSON property lastTransferDuration
3259 3260 3261 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 3259 def last_transfer_duration @last_transfer_duration end |
#last_transfer_end_time ⇒ String
Time when last transfer completed.
Corresponds to the JSON property lastTransferEndTime
3264 3265 3266 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 3264 def last_transfer_end_time @last_transfer_end_time end |
#last_transfer_error ⇒ String
A message describing the cause of the last transfer failure.
Corresponds to the JSON property lastTransferError
3269 3270 3271 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 3269 def last_transfer_error @last_transfer_error end |
#total_transfer_duration ⇒ String
Cumulative time taken across all transfers for the replication relationship.
Corresponds to the JSON property totalTransferDuration
3274 3275 3276 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 3274 def total_transfer_duration @total_transfer_duration end |
#transfer_bytes ⇒ Fixnum
Cumulative bytes transferred so far for the replication relationship.
Corresponds to the JSON property transferBytes
3279 3280 3281 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 3279 def transfer_bytes @transfer_bytes end |
#update_time ⇒ String
Time when progress was updated last.
Corresponds to the JSON property updateTime
3284 3285 3286 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 3284 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3291 3292 3293 3294 3295 3296 3297 3298 3299 3300 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 3291 def update!(**args) @lag_duration = args[:lag_duration] if args.key?(:lag_duration) @last_transfer_bytes = args[:last_transfer_bytes] if args.key?(:last_transfer_bytes) @last_transfer_duration = args[:last_transfer_duration] if args.key?(:last_transfer_duration) @last_transfer_end_time = args[:last_transfer_end_time] if args.key?(:last_transfer_end_time) @last_transfer_error = args[:last_transfer_error] if args.key?(:last_transfer_error) @total_transfer_duration = args[:total_transfer_duration] if args.key?(:total_transfer_duration) @transfer_bytes = args[:transfer_bytes] if args.key?(:transfer_bytes) @update_time = args[:update_time] if args.key?(:update_time) end |