Class: Google::Apis::NetappV1::TransferStats
- Inherits:
-
Object
- Object
- Google::Apis::NetappV1::TransferStats
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/netapp_v1/classes.rb,
lib/google/apis/netapp_v1/representations.rb,
lib/google/apis/netapp_v1/representations.rb
Overview
TransferStats reports all statistics related to replication transfer.
Instance Attribute Summary collapse
-
#lag_duration ⇒ String
Lag duration indicates the duration by which Destination region volume content lags behind the primary region volume content.
-
#last_transfer_bytes ⇒ Fixnum
Last transfer size in bytes.
-
#last_transfer_duration ⇒ String
Time taken during last transfer.
-
#last_transfer_end_time ⇒ String
Time when last transfer completed.
-
#last_transfer_error ⇒ String
A message describing the cause of the last transfer failure.
-
#total_transfer_duration ⇒ String
Cumulative time taken across all transfers for the replication relationship.
-
#transfer_bytes ⇒ Fixnum
Cumulative bytes transferred so far for the replication relationship.
-
#update_time ⇒ String
Time when progress was updated last.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TransferStats
constructor
A new instance of TransferStats.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TransferStats
Returns a new instance of TransferStats.
3138 3139 3140 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 3138 def initialize(**args) update!(**args) end |
Instance Attribute Details
#lag_duration ⇒ String
Lag duration indicates the duration by which Destination region volume content
lags behind the primary region volume content.
Corresponds to the JSON property lagDuration
3101 3102 3103 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 3101 def lag_duration @lag_duration end |
#last_transfer_bytes ⇒ Fixnum
Last transfer size in bytes.
Corresponds to the JSON property lastTransferBytes
3106 3107 3108 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 3106 def last_transfer_bytes @last_transfer_bytes end |
#last_transfer_duration ⇒ String
Time taken during last transfer.
Corresponds to the JSON property lastTransferDuration
3111 3112 3113 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 3111 def last_transfer_duration @last_transfer_duration end |
#last_transfer_end_time ⇒ String
Time when last transfer completed.
Corresponds to the JSON property lastTransferEndTime
3116 3117 3118 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 3116 def last_transfer_end_time @last_transfer_end_time end |
#last_transfer_error ⇒ String
A message describing the cause of the last transfer failure.
Corresponds to the JSON property lastTransferError
3121 3122 3123 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 3121 def last_transfer_error @last_transfer_error end |
#total_transfer_duration ⇒ String
Cumulative time taken across all transfers for the replication relationship.
Corresponds to the JSON property totalTransferDuration
3126 3127 3128 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 3126 def total_transfer_duration @total_transfer_duration end |
#transfer_bytes ⇒ Fixnum
Cumulative bytes transferred so far for the replication relationship.
Corresponds to the JSON property transferBytes
3131 3132 3133 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 3131 def transfer_bytes @transfer_bytes end |
#update_time ⇒ String
Time when progress was updated last.
Corresponds to the JSON property updateTime
3136 3137 3138 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 3136 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3143 3144 3145 3146 3147 3148 3149 3150 3151 3152 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 3143 def update!(**args) @lag_duration = args[:lag_duration] if args.key?(:lag_duration) @last_transfer_bytes = args[:last_transfer_bytes] if args.key?(:last_transfer_bytes) @last_transfer_duration = args[:last_transfer_duration] if args.key?(:last_transfer_duration) @last_transfer_end_time = args[:last_transfer_end_time] if args.key?(:last_transfer_end_time) @last_transfer_error = args[:last_transfer_error] if args.key?(:last_transfer_error) @total_transfer_duration = args[:total_transfer_duration] if args.key?(:total_transfer_duration) @transfer_bytes = args[:transfer_bytes] if args.key?(:transfer_bytes) @update_time = args[:update_time] if args.key?(:update_time) end |