Class: Google::Apis::NetappV1::UserCommands

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/netapp_v1/classes.rb,
lib/google/apis/netapp_v1/representations.rb,
lib/google/apis/netapp_v1/representations.rb

Overview

UserCommands contains the commands to be executed by the customer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UserCommands

Returns a new instance of UserCommands.



3346
3347
3348
# File 'lib/google/apis/netapp_v1/classes.rb', line 3346

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#commandsArray<String>

Output only. List of commands to be executed by the customer. Corresponds to the JSON property commands

Returns:

  • (Array<String>)


3344
3345
3346
# File 'lib/google/apis/netapp_v1/classes.rb', line 3344

def commands
  @commands
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3351
3352
3353
# File 'lib/google/apis/netapp_v1/classes.rb', line 3351

def update!(**args)
  @commands = args[:commands] if args.key?(:commands)
end