Class: Google::Apis::NetappV1::UserCommands

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/netapp_v1/classes.rb,
lib/google/apis/netapp_v1/representations.rb,
lib/google/apis/netapp_v1/representations.rb

Overview

UserCommands contains the commands to be executed by the customer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UserCommands

Returns a new instance of UserCommands.



3164
3165
3166
# File 'lib/google/apis/netapp_v1/classes.rb', line 3164

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#commandsArray<String>

Output only. List of commands to be executed by the customer. Corresponds to the JSON property commands

Returns:

  • (Array<String>)


3162
3163
3164
# File 'lib/google/apis/netapp_v1/classes.rb', line 3162

def commands
  @commands
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3169
3170
3171
# File 'lib/google/apis/netapp_v1/classes.rb', line 3169

def update!(**args)
  @commands = args[:commands] if args.key?(:commands)
end