Class: Google::Apis::NetappV1::ValidateDirectoryServiceRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/netapp_v1/classes.rb,
lib/google/apis/netapp_v1/representations.rb,
lib/google/apis/netapp_v1/representations.rb

Overview

ValidateDirectoryServiceRequest validates the directory service policy attached to the storage pool.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ValidateDirectoryServiceRequest

Returns a new instance of ValidateDirectoryServiceRequest.



3184
3185
3186
# File 'lib/google/apis/netapp_v1/classes.rb', line 3184

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#directory_service_typeString

Type of directory service policy attached to the storage pool. Corresponds to the JSON property directoryServiceType

Returns:

  • (String)


3182
3183
3184
# File 'lib/google/apis/netapp_v1/classes.rb', line 3182

def directory_service_type
  @directory_service_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3189
3190
3191
# File 'lib/google/apis/netapp_v1/classes.rb', line 3189

def update!(**args)
  @directory_service_type = args[:directory_service_type] if args.key?(:directory_service_type)
end