Class: Google::Apis::NetappV1::VerifyKmsConfigResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/netapp_v1/classes.rb,
lib/google/apis/netapp_v1/representations.rb,
lib/google/apis/netapp_v1/representations.rb

Overview

VerifyKmsConfigResponse contains the information if the config is correctly and error message.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VerifyKmsConfigResponse

Returns a new instance of VerifyKmsConfigResponse.



3229
3230
3231
# File 'lib/google/apis/netapp_v1/classes.rb', line 3229

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#health_errorString

Output only. Error message if config is not healthy. Corresponds to the JSON property healthError

Returns:

  • (String)


3215
3216
3217
# File 'lib/google/apis/netapp_v1/classes.rb', line 3215

def health_error
  @health_error
end

#healthyBoolean Also known as: healthy?

Output only. If the customer key configured correctly to the encrypt volume. Corresponds to the JSON property healthy

Returns:

  • (Boolean)


3220
3221
3222
# File 'lib/google/apis/netapp_v1/classes.rb', line 3220

def healthy
  @healthy
end

#instructionsString

Output only. Instructions for the customers to provide the access to the encryption key. Corresponds to the JSON property instructions

Returns:

  • (String)


3227
3228
3229
# File 'lib/google/apis/netapp_v1/classes.rb', line 3227

def instructions
  @instructions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3234
3235
3236
3237
3238
# File 'lib/google/apis/netapp_v1/classes.rb', line 3234

def update!(**args)
  @health_error = args[:health_error] if args.key?(:health_error)
  @healthy = args[:healthy] if args.key?(:healthy)
  @instructions = args[:instructions] if args.key?(:instructions)
end