Class: Google::Apis::NetappV1::VerifyKmsConfigResponse
- Inherits:
-
Object
- Object
- Google::Apis::NetappV1::VerifyKmsConfigResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/netapp_v1/classes.rb,
lib/google/apis/netapp_v1/representations.rb,
lib/google/apis/netapp_v1/representations.rb
Overview
VerifyKmsConfigResponse contains the information if the config is correctly and error message.
Instance Attribute Summary collapse
-
#health_error ⇒ String
Output only.
-
#healthy ⇒ Boolean
(also: #healthy?)
Output only.
-
#instructions ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VerifyKmsConfigResponse
constructor
A new instance of VerifyKmsConfigResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VerifyKmsConfigResponse
Returns a new instance of VerifyKmsConfigResponse.
3229 3230 3231 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 3229 def initialize(**args) update!(**args) end |
Instance Attribute Details
#health_error ⇒ String
Output only. Error message if config is not healthy.
Corresponds to the JSON property healthError
3215 3216 3217 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 3215 def health_error @health_error end |
#healthy ⇒ Boolean Also known as: healthy?
Output only. If the customer key configured correctly to the encrypt volume.
Corresponds to the JSON property healthy
3220 3221 3222 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 3220 def healthy @healthy end |
#instructions ⇒ String
Output only. Instructions for the customers to provide the access to the
encryption key.
Corresponds to the JSON property instructions
3227 3228 3229 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 3227 def instructions @instructions end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3234 3235 3236 3237 3238 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 3234 def update!(**args) @health_error = args[:health_error] if args.key?(:health_error) @healthy = args[:healthy] if args.key?(:healthy) @instructions = args[:instructions] if args.key?(:instructions) end |