Class: Google::Apis::NetappV1::WeeklySchedule
- Inherits:
-
Object
- Object
- Google::Apis::NetappV1::WeeklySchedule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/netapp_v1/classes.rb,
lib/google/apis/netapp_v1/representations.rb,
lib/google/apis/netapp_v1/representations.rb
Overview
Make a snapshot every week e.g. at Monday 04:00, Wednesday 05:20, Sunday 23:50
Instance Attribute Summary collapse
-
#day ⇒ String
Set the day or days of the week to make a snapshot.
-
#hour ⇒ Float
Set the hour to start the snapshot (0-23), defaults to midnight (0).
-
#minute ⇒ Float
Set the minute of the hour to start the snapshot (0-59), defaults to the top of the hour (0).
-
#snapshots_to_keep ⇒ Float
The maximum number of Snapshots to keep for the hourly schedule Corresponds to the JSON property
snapshotsToKeep.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WeeklySchedule
constructor
A new instance of WeeklySchedule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WeeklySchedule
Returns a new instance of WeeklySchedule.
3781 3782 3783 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 3781 def initialize(**args) update!(**args) end |
Instance Attribute Details
#day ⇒ String
Set the day or days of the week to make a snapshot. Accepts a comma separated
days of the week. Defaults to 'Sunday'.
Corresponds to the JSON property day
3763 3764 3765 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 3763 def day @day end |
#hour ⇒ Float
Set the hour to start the snapshot (0-23), defaults to midnight (0).
Corresponds to the JSON property hour
3768 3769 3770 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 3768 def hour @hour end |
#minute ⇒ Float
Set the minute of the hour to start the snapshot (0-59), defaults to the top
of the hour (0).
Corresponds to the JSON property minute
3774 3775 3776 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 3774 def minute @minute end |
#snapshots_to_keep ⇒ Float
The maximum number of Snapshots to keep for the hourly schedule
Corresponds to the JSON property snapshotsToKeep
3779 3780 3781 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 3779 def snapshots_to_keep @snapshots_to_keep end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3786 3787 3788 3789 3790 3791 |
# File 'lib/google/apis/netapp_v1/classes.rb', line 3786 def update!(**args) @day = args[:day] if args.key?(:day) @hour = args[:hour] if args.key?(:hour) @minute = args[:minute] if args.key?(:minute) @snapshots_to_keep = args[:snapshots_to_keep] if args.key?(:snapshots_to_keep) end |